# THIS FILE WAS AUTOMATICALLY GENERATED BY "generate_dicts_from_data_json.py" DO NOT CHANGE MANUALLY!
# ANY CHANGE WILL BE OVERWRITTEN

from typing import Dict

from sc2.ids.ability_id import AbilityId

# from ..ids.buff_id import BuffId
# from ..ids.effect_id import EffectId

GENERIC_REDIRECT_ABILITIES: Dict[AbilityId, AbilityId] = {
    AbilityId.ARMORYRESEARCH_TERRANSHIPWEAPONSLEVEL1: AbilityId.RESEARCH_TERRANSHIPWEAPONS,
    AbilityId.ARMORYRESEARCH_TERRANSHIPWEAPONSLEVEL2: AbilityId.RESEARCH_TERRANSHIPWEAPONS,
    AbilityId.ARMORYRESEARCH_TERRANSHIPWEAPONSLEVEL3: AbilityId.RESEARCH_TERRANSHIPWEAPONS,
    AbilityId.ARMORYRESEARCH_TERRANVEHICLEANDSHIPPLATINGLEVEL1: AbilityId.RESEARCH_TERRANVEHICLEANDSHIPPLATING,
    AbilityId.ARMORYRESEARCH_TERRANVEHICLEANDSHIPPLATINGLEVEL2: AbilityId.RESEARCH_TERRANVEHICLEANDSHIPPLATING,
    AbilityId.ARMORYRESEARCH_TERRANVEHICLEANDSHIPPLATINGLEVEL3: AbilityId.RESEARCH_TERRANVEHICLEANDSHIPPLATING,
    AbilityId.ARMORYRESEARCH_TERRANVEHICLEWEAPONSLEVEL1: AbilityId.RESEARCH_TERRANVEHICLEWEAPONS,
    AbilityId.ARMORYRESEARCH_TERRANVEHICLEWEAPONSLEVEL2: AbilityId.RESEARCH_TERRANVEHICLEWEAPONS,
    AbilityId.ARMORYRESEARCH_TERRANVEHICLEWEAPONSLEVEL3: AbilityId.RESEARCH_TERRANVEHICLEWEAPONS,
    AbilityId.ATTACKPROTOSSBUILDING_ATTACKBUILDING: AbilityId.ATTACK,
    AbilityId.ATTACK_ATTACK: AbilityId.ATTACK,
    AbilityId.ATTACK_BATTLECRUISER: AbilityId.ATTACK,
    AbilityId.ATTACK_REDIRECT: AbilityId.ATTACK,
    AbilityId.BEHAVIOR_CLOAKOFF_BANSHEE: AbilityId.BEHAVIOR_CLOAKOFF,
    AbilityId.BEHAVIOR_CLOAKOFF_GHOST: AbilityId.BEHAVIOR_CLOAKOFF,
    AbilityId.BEHAVIOR_CLOAKON_BANSHEE: AbilityId.BEHAVIOR_CLOAKON,
    AbilityId.BEHAVIOR_CLOAKON_GHOST: AbilityId.BEHAVIOR_CLOAKON,
    AbilityId.BEHAVIOR_HOLDFIREOFF_GHOST: AbilityId.BEHAVIOR_HOLDFIREOFF,
    AbilityId.BEHAVIOR_HOLDFIREOFF_LURKER: AbilityId.BEHAVIOR_HOLDFIREOFF,
    AbilityId.BEHAVIOR_HOLDFIREON_GHOST: AbilityId.BEHAVIOR_HOLDFIREON,
    AbilityId.BEHAVIOR_HOLDFIREON_LURKER: AbilityId.BEHAVIOR_HOLDFIREON,
    AbilityId.BROODLORDQUEUE2_CANCEL: AbilityId.CANCEL_LAST,
    AbilityId.BROODLORDQUEUE2_CANCELSLOT: AbilityId.CANCEL_SLOT,
    AbilityId.BUILDINPROGRESSNYDUSCANAL_CANCEL: AbilityId.CANCEL,
    AbilityId.BUILDNYDUSCANAL_CANCEL: AbilityId.HALT,
    AbilityId.BUILD_CREEPTUMOR_QUEEN: AbilityId.BUILD_CREEPTUMOR,
    AbilityId.BUILD_CREEPTUMOR_TUMOR: AbilityId.BUILD_CREEPTUMOR,
    AbilityId.BUILD_REACTOR_BARRACKS: AbilityId.BUILD_REACTOR,
    AbilityId.BUILD_REACTOR_FACTORY: AbilityId.BUILD_REACTOR,
    AbilityId.BUILD_REACTOR_STARPORT: AbilityId.BUILD_REACTOR,
    AbilityId.BUILD_TECHLAB_BARRACKS: AbilityId.BUILD_TECHLAB,
    AbilityId.BUILD_TECHLAB_FACTORY: AbilityId.BUILD_TECHLAB,
    AbilityId.BUILD_TECHLAB_STARPORT: AbilityId.BUILD_TECHLAB,
    AbilityId.BURROWBANELINGDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWCREEPTUMORDOWN_BURROWDOWN: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_BANELING: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_DRONE: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_HYDRALISK: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_INFESTOR: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_INFESTORTERRAN: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_LURKER: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_QUEEN: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_RAVAGER: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_ROACH: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_SWARMHOST: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_ULTRALISK: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_WIDOWMINE: AbilityId.BURROWDOWN,
    AbilityId.BURROWDOWN_ZERGLING: AbilityId.BURROWDOWN,
    AbilityId.BURROWDRONEDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWHYDRALISKDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWINFESTORDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWLURKERMPDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWQUEENDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWRAVAGERDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWROACHDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.BURROWUP_BANELING: AbilityId.BURROWUP,
    AbilityId.BURROWUP_DRONE: AbilityId.BURROWUP,
    AbilityId.BURROWUP_HYDRALISK: AbilityId.BURROWUP,
    AbilityId.BURROWUP_INFESTOR: AbilityId.BURROWUP,
    AbilityId.BURROWUP_INFESTORTERRAN: AbilityId.BURROWUP,
    AbilityId.BURROWUP_LURKER: AbilityId.BURROWUP,
    AbilityId.BURROWUP_QUEEN: AbilityId.BURROWUP,
    AbilityId.BURROWUP_RAVAGER: AbilityId.BURROWUP,
    AbilityId.BURROWUP_ROACH: AbilityId.BURROWUP,
    AbilityId.BURROWUP_SWARMHOST: AbilityId.BURROWUP,
    AbilityId.BURROWUP_ULTRALISK: AbilityId.BURROWUP,
    AbilityId.BURROWUP_WIDOWMINE: AbilityId.BURROWUP,
    AbilityId.BURROWUP_ZERGLING: AbilityId.BURROWUP,
    AbilityId.BURROWZERGLINGDOWN_CANCEL: AbilityId.CANCEL,
    AbilityId.CANCELSLOT_ADDON: AbilityId.CANCEL_SLOT,
    AbilityId.CANCELSLOT_HANGARQUEUE5: AbilityId.CANCEL_SLOT,
    AbilityId.CANCELSLOT_QUEUE1: AbilityId.CANCEL_SLOT,
    AbilityId.CANCELSLOT_QUEUE5: AbilityId.CANCEL_SLOT,
    AbilityId.CANCELSLOT_QUEUECANCELTOSELECTION: AbilityId.CANCEL_SLOT,
    AbilityId.CANCELSLOT_QUEUEPASSIVE: AbilityId.CANCEL_SLOT,
    AbilityId.CANCELSLOT_QUEUEPASSIVECANCELTOSELECTION: AbilityId.CANCEL_SLOT,
    AbilityId.CANCEL_ADEPTPHASESHIFT: AbilityId.CANCEL,
    AbilityId.CANCEL_ADEPTSHADEPHASESHIFT: AbilityId.CANCEL,
    AbilityId.CANCEL_BARRACKSADDON: AbilityId.CANCEL,
    AbilityId.CANCEL_BUILDINPROGRESS: AbilityId.CANCEL,
    AbilityId.CANCEL_CREEPTUMOR: AbilityId.CANCEL,
    AbilityId.CANCEL_FACTORYADDON: AbilityId.CANCEL,
    AbilityId.CANCEL_GRAVITONBEAM: AbilityId.CANCEL,
    AbilityId.CANCEL_HANGARQUEUE5: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_LOCKON: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHBROODLORD: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHGREATERSPIRE: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHHIVE: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHLAIR: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHLURKER: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHMOTHERSHIP: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHORBITAL: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHOVERLORDTRANSPORT: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHOVERSEER: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHPLANETARYFORTRESS: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHRAVAGER: AbilityId.CANCEL,
    AbilityId.CANCEL_MORPHTHOREXPLOSIVEMODE: AbilityId.CANCEL,
    AbilityId.CANCEL_NEURALPARASITE: AbilityId.CANCEL,
    AbilityId.CANCEL_NUKE: AbilityId.CANCEL,
    AbilityId.CANCEL_QUEUE1: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_QUEUE5: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_QUEUEADDON: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_QUEUECANCELTOSELECTION: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_QUEUEPASIVE: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_QUEUEPASSIVECANCELTOSELECTION: AbilityId.CANCEL_LAST,
    AbilityId.CANCEL_SPINECRAWLERROOT: AbilityId.CANCEL,
    AbilityId.CANCEL_SPORECRAWLERROOT: AbilityId.CANCEL,
    AbilityId.CANCEL_STARPORTADDON: AbilityId.CANCEL,
    AbilityId.CANCEL_STASISTRAP: AbilityId.CANCEL,
    AbilityId.CANCEL_VOIDRAYPRISMATICALIGNMENT: AbilityId.CANCEL,
    AbilityId.CYBERNETICSCORERESEARCH_PROTOSSAIRARMORLEVEL1: AbilityId.RESEARCH_PROTOSSAIRARMOR,
    AbilityId.CYBERNETICSCORERESEARCH_PROTOSSAIRARMORLEVEL2: AbilityId.RESEARCH_PROTOSSAIRARMOR,
    AbilityId.CYBERNETICSCORERESEARCH_PROTOSSAIRARMORLEVEL3: AbilityId.RESEARCH_PROTOSSAIRARMOR,
    AbilityId.CYBERNETICSCORERESEARCH_PROTOSSAIRWEAPONSLEVEL1: AbilityId.RESEARCH_PROTOSSAIRWEAPONS,
    AbilityId.CYBERNETICSCORERESEARCH_PROTOSSAIRWEAPONSLEVEL2: AbilityId.RESEARCH_PROTOSSAIRWEAPONS,
    AbilityId.CYBERNETICSCORERESEARCH_PROTOSSAIRWEAPONSLEVEL3: AbilityId.RESEARCH_PROTOSSAIRWEAPONS,
    AbilityId.DEFILERMPBURROW_BURROWDOWN: AbilityId.BURROWDOWN,
    AbilityId.DEFILERMPBURROW_CANCEL: AbilityId.CANCEL,
    AbilityId.DEFILERMPUNBURROW_BURROWUP: AbilityId.BURROWUP,
    AbilityId.EFFECT_BLINK_STALKER: AbilityId.EFFECT_BLINK,
    AbilityId.EFFECT_MASSRECALL_MOTHERSHIPCORE: AbilityId.EFFECT_MASSRECALL,
    AbilityId.EFFECT_MASSRECALL_NEXUS: AbilityId.EFFECT_MASSRECALL,
    AbilityId.EFFECT_MASSRECALL_STRATEGICRECALL: AbilityId.EFFECT_MASSRECALL,
    AbilityId.EFFECT_REPAIR_MULE: AbilityId.EFFECT_REPAIR,
    AbilityId.EFFECT_REPAIR_REPAIRDRONE: AbilityId.EFFECT_REPAIR,
    AbilityId.EFFECT_REPAIR_SCV: AbilityId.EFFECT_REPAIR,
    AbilityId.EFFECT_SHADOWSTRIDE: AbilityId.EFFECT_BLINK,
    AbilityId.EFFECT_SPRAY_PROTOSS: AbilityId.EFFECT_SPRAY,
    AbilityId.EFFECT_SPRAY_TERRAN: AbilityId.EFFECT_SPRAY,
    AbilityId.EFFECT_SPRAY_ZERG: AbilityId.EFFECT_SPRAY,
    AbilityId.EFFECT_STIM_MARAUDER: AbilityId.EFFECT_STIM,
    AbilityId.EFFECT_STIM_MARAUDER_REDIRECT: AbilityId.EFFECT_STIM,
    AbilityId.EFFECT_STIM_MARINE: AbilityId.EFFECT_STIM,
    AbilityId.EFFECT_STIM_MARINE_REDIRECT: AbilityId.EFFECT_STIM,
    AbilityId.ENGINEERINGBAYRESEARCH_TERRANINFANTRYARMORLEVEL1: AbilityId.RESEARCH_TERRANINFANTRYARMOR,
    AbilityId.ENGINEERINGBAYRESEARCH_TERRANINFANTRYARMORLEVEL2: AbilityId.RESEARCH_TERRANINFANTRYARMOR,
    AbilityId.ENGINEERINGBAYRESEARCH_TERRANINFANTRYARMORLEVEL3: AbilityId.RESEARCH_TERRANINFANTRYARMOR,
    AbilityId.ENGINEERINGBAYRESEARCH_TERRANINFANTRYWEAPONSLEVEL1: AbilityId.RESEARCH_TERRANINFANTRYWEAPONS,
    AbilityId.ENGINEERINGBAYRESEARCH_TERRANINFANTRYWEAPONSLEVEL2: AbilityId.RESEARCH_TERRANINFANTRYWEAPONS,
    AbilityId.ENGINEERINGBAYRESEARCH_TERRANINFANTRYWEAPONSLEVEL3: AbilityId.RESEARCH_TERRANINFANTRYWEAPONS,
    AbilityId.FORCEFIELD_CANCEL: AbilityId.CANCEL,
    AbilityId.FORGERESEARCH_PROTOSSGROUNDARMORLEVEL1: AbilityId.RESEARCH_PROTOSSGROUNDARMOR,
    AbilityId.FORGERESEARCH_PROTOSSGROUNDARMORLEVEL2: AbilityId.RESEARCH_PROTOSSGROUNDARMOR,
    AbilityId.FORGERESEARCH_PROTOSSGROUNDARMORLEVEL3: AbilityId.RESEARCH_PROTOSSGROUNDARMOR,
    AbilityId.FORGERESEARCH_PROTOSSGROUNDWEAPONSLEVEL1: AbilityId.RESEARCH_PROTOSSGROUNDWEAPONS,
    AbilityId.FORGERESEARCH_PROTOSSGROUNDWEAPONSLEVEL2: AbilityId.RESEARCH_PROTOSSGROUNDWEAPONS,
    AbilityId.FORGERESEARCH_PROTOSSGROUNDWEAPONSLEVEL3: AbilityId.RESEARCH_PROTOSSGROUNDWEAPONS,
    AbilityId.FORGERESEARCH_PROTOSSSHIELDSLEVEL1: AbilityId.RESEARCH_PROTOSSSHIELDS,
    AbilityId.FORGERESEARCH_PROTOSSSHIELDSLEVEL2: AbilityId.RESEARCH_PROTOSSSHIELDS,
    AbilityId.FORGERESEARCH_PROTOSSSHIELDSLEVEL3: AbilityId.RESEARCH_PROTOSSSHIELDS,
    AbilityId.HALT_BUILDING: AbilityId.HALT,
    AbilityId.HALT_TERRANBUILD: AbilityId.HALT,
    AbilityId.HARVEST_GATHER_DRONE: AbilityId.HARVEST_GATHER,
    AbilityId.HARVEST_GATHER_MULE: AbilityId.HARVEST_GATHER,
    AbilityId.HARVEST_GATHER_PROBE: AbilityId.HARVEST_GATHER,
    AbilityId.HARVEST_GATHER_SCV: AbilityId.HARVEST_GATHER,
    AbilityId.HARVEST_RETURN_DRONE: AbilityId.HARVEST_RETURN,
    AbilityId.HARVEST_RETURN_MULE: AbilityId.HARVEST_RETURN,
    AbilityId.HARVEST_RETURN_PROBE: AbilityId.HARVEST_RETURN,
    AbilityId.HARVEST_RETURN_SCV: AbilityId.HARVEST_RETURN,
    AbilityId.HOLDPOSITION_BATTLECRUISER: AbilityId.HOLDPOSITION,
    AbilityId.HOLDPOSITION_HOLD: AbilityId.HOLDPOSITION,
    AbilityId.LAND_BARRACKS: AbilityId.LAND,
    AbilityId.LAND_COMMANDCENTER: AbilityId.LAND,
    AbilityId.LAND_FACTORY: AbilityId.LAND,
    AbilityId.LAND_ORBITALCOMMAND: AbilityId.LAND,
    AbilityId.LAND_STARPORT: AbilityId.LAND,
    AbilityId.LIFT_BARRACKS: AbilityId.LIFT,
    AbilityId.LIFT_COMMANDCENTER: AbilityId.LIFT,
    AbilityId.LIFT_FACTORY: AbilityId.LIFT,
    AbilityId.LIFT_ORBITALCOMMAND: AbilityId.LIFT,
    AbilityId.LIFT_STARPORT: AbilityId.LIFT,
    AbilityId.LOADALL_COMMANDCENTER: AbilityId.LOADALL,
    AbilityId.LOAD_BUNKER: AbilityId.LOAD,
    AbilityId.LOAD_MEDIVAC: AbilityId.LOAD,
    AbilityId.LOAD_NYDUSNETWORK: AbilityId.LOAD,
    AbilityId.LOAD_NYDUSWORM: AbilityId.LOAD,
    AbilityId.LOAD_OVERLORD: AbilityId.LOAD,
    AbilityId.LOAD_WARPPRISM: AbilityId.LOAD,
    AbilityId.MERGEABLE_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHBACKTOGATEWAY_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLEPURIFIERTOWERDEBRIS_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPLEFTGREEN_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPLEFT_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPRIGHTGREEN_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPRIGHT_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLEROCKTOWERDEBRIS_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLETERRANTOWERDEBRISRAMPLEFT_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLETERRANTOWERDEBRISRAMPRIGHT_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOCOLLAPSIBLETERRANTOWERDEBRIS_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTODEVOURERMP_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOGUARDIANMP_CANCEL: AbilityId.CANCEL,
    AbilityId.MORPHTOSWARMHOSTBURROWEDMP_CANCEL: AbilityId.CANCEL,
    AbilityId.MOVE_BATTLECRUISER: AbilityId.MOVE,
    AbilityId.MOVE_MOVE: AbilityId.MOVE,
    AbilityId.PATROL_BATTLECRUISER: AbilityId.PATROL,
    AbilityId.PATROL_PATROL: AbilityId.PATROL,
    AbilityId.PHASINGMODE_CANCEL: AbilityId.CANCEL,
    AbilityId.PROTOSSBUILD_CANCEL: AbilityId.HALT,
    AbilityId.QUEENBUILD_CANCEL: AbilityId.HALT,
    AbilityId.RALLY_BUILDING: AbilityId.RALLY_UNITS,
    AbilityId.RALLY_COMMANDCENTER: AbilityId.RALLY_WORKERS,
    AbilityId.RALLY_HATCHERY_UNITS: AbilityId.RALLY_UNITS,
    AbilityId.RALLY_HATCHERY_WORKERS: AbilityId.RALLY_WORKERS,
    AbilityId.RALLY_MORPHING_UNIT: AbilityId.RALLY_UNITS,
    AbilityId.RALLY_NEXUS: AbilityId.RALLY_WORKERS,
    AbilityId.RESEARCH_ZERGFLYERARMORLEVEL1: AbilityId.RESEARCH_ZERGFLYERARMOR,
    AbilityId.RESEARCH_ZERGFLYERARMORLEVEL2: AbilityId.RESEARCH_ZERGFLYERARMOR,
    AbilityId.RESEARCH_ZERGFLYERARMORLEVEL3: AbilityId.RESEARCH_ZERGFLYERARMOR,
    AbilityId.RESEARCH_ZERGFLYERATTACKLEVEL1: AbilityId.RESEARCH_ZERGFLYERATTACK,
    AbilityId.RESEARCH_ZERGFLYERATTACKLEVEL2: AbilityId.RESEARCH_ZERGFLYERATTACK,
    AbilityId.RESEARCH_ZERGFLYERATTACKLEVEL3: AbilityId.RESEARCH_ZERGFLYERATTACK,
    AbilityId.RESEARCH_ZERGGROUNDARMORLEVEL1: AbilityId.RESEARCH_ZERGGROUNDARMOR,
    AbilityId.RESEARCH_ZERGGROUNDARMORLEVEL2: AbilityId.RESEARCH_ZERGGROUNDARMOR,
    AbilityId.RESEARCH_ZERGGROUNDARMORLEVEL3: AbilityId.RESEARCH_ZERGGROUNDARMOR,
    AbilityId.RESEARCH_ZERGMELEEWEAPONSLEVEL1: AbilityId.RESEARCH_ZERGMELEEWEAPONS,
    AbilityId.RESEARCH_ZERGMELEEWEAPONSLEVEL2: AbilityId.RESEARCH_ZERGMELEEWEAPONS,
    AbilityId.RESEARCH_ZERGMELEEWEAPONSLEVEL3: AbilityId.RESEARCH_ZERGMELEEWEAPONS,
    AbilityId.RESEARCH_ZERGMISSILEWEAPONSLEVEL1: AbilityId.RESEARCH_ZERGMISSILEWEAPONS,
    AbilityId.RESEARCH_ZERGMISSILEWEAPONSLEVEL2: AbilityId.RESEARCH_ZERGMISSILEWEAPONS,
    AbilityId.RESEARCH_ZERGMISSILEWEAPONSLEVEL3: AbilityId.RESEARCH_ZERGMISSILEWEAPONS,
    AbilityId.SCAN_MOVE: AbilityId.ATTACK,
    AbilityId.SHIELDBATTERYRECHARGEEX5_STOP: AbilityId.CANCEL,
    AbilityId.SPINECRAWLERROOT_SPINECRAWLERROOT: AbilityId.MORPH_ROOT,
    AbilityId.SPINECRAWLERUPROOT_CANCEL: AbilityId.CANCEL,
    AbilityId.SPINECRAWLERUPROOT_SPINECRAWLERUPROOT: AbilityId.MORPH_UPROOT,
    AbilityId.SPORECRAWLERROOT_SPORECRAWLERROOT: AbilityId.MORPH_ROOT,
    AbilityId.SPORECRAWLERUPROOT_CANCEL: AbilityId.CANCEL,
    AbilityId.SPORECRAWLERUPROOT_SPORECRAWLERUPROOT: AbilityId.MORPH_UPROOT,
    AbilityId.STOP_BATTLECRUISER: AbilityId.STOP,
    AbilityId.STOP_BUILDING: AbilityId.STOP,
    AbilityId.STOP_CHEER: AbilityId.STOP,
    AbilityId.STOP_DANCE: AbilityId.STOP,
    AbilityId.STOP_HOLDFIRESPECIAL: AbilityId.STOP,
    AbilityId.STOP_REDIRECT: AbilityId.STOP,
    AbilityId.STOP_STOP: AbilityId.STOP,
    AbilityId.TESTZERG_CANCEL: AbilityId.CANCEL,
    AbilityId.THORAPMODE_CANCEL: AbilityId.CANCEL,
    AbilityId.TRANSPORTMODE_CANCEL: AbilityId.CANCEL,
    AbilityId.UNLOADALLAT_MEDIVAC: AbilityId.UNLOADALLAT,
    AbilityId.UNLOADALLAT_OVERLORD: AbilityId.UNLOADALLAT,
    AbilityId.UNLOADALLAT_WARPPRISM: AbilityId.UNLOADALLAT,
    AbilityId.UNLOADALL_BUNKER: AbilityId.UNLOADALL,
    AbilityId.UNLOADALL_COMMANDCENTER: AbilityId.UNLOADALL,
    AbilityId.UNLOADALL_NYDASNETWORK: AbilityId.UNLOADALL,
    AbilityId.UNLOADALL_NYDUSWORM: AbilityId.UNLOADALL,
    AbilityId.UNLOADALL_WARPPRISM: AbilityId.UNLOADALL,
    AbilityId.UNLOADUNIT_BUNKER: AbilityId.UNLOADUNIT,
    AbilityId.UNLOADUNIT_COMMANDCENTER: AbilityId.UNLOADUNIT,
    AbilityId.UNLOADUNIT_MEDIVAC: AbilityId.UNLOADUNIT,
    AbilityId.UNLOADUNIT_NYDASNETWORK: AbilityId.UNLOADUNIT,
    AbilityId.UNLOADUNIT_OVERLORD: AbilityId.UNLOADUNIT,
    AbilityId.UNLOADUNIT_WARPPRISM: AbilityId.UNLOADUNIT,
    AbilityId.UPGRADETOWARPGATE_CANCEL: AbilityId.CANCEL,
    AbilityId.WARPABLE_CANCEL: AbilityId.CANCEL,
    AbilityId.WIDOWMINEBURROW_CANCEL: AbilityId.CANCEL,
    AbilityId.ZERGBUILD_CANCEL: AbilityId.HALT
}
