# DO NOT EDIT!
# This file was automatically generated by "generate_ids.py"

import enum


class AbilityId(enum.Enum):
    NULL_NULL = 0
    SMART = 1
    TAUNT_TAUNT = 2
    STOP_STOP = 4
    STOP_HOLDFIRESPECIAL = 5
    STOP_CHEER = 6
    STOP_DANCE = 7
    HOLDFIRE_STOPSPECIAL = 10
    HOLDFIRE_HOLDFIRE = 11
    MOVE_MOVE = 16
    PATROL_PATROL = 17
    HOLDPOSITION_HOLD = 18
    SCAN_MOVE = 19
    MOVE_TURN = 20
    BEACON_CANCEL = 21
    BEACON_BEACONMOVE = 22
    ATTACK_ATTACK = 23
    ATTACK_ATTACKTOWARDS = 24
    ATTACK_ATTACKBARRAGE = 25
    EFFECT_SPRAY_TERRAN = 26
    EFFECT_SPRAY_ZERG = 28
    EFFECT_SPRAY_PROTOSS = 30
    EFFECT_SALVAGE = 32
    CORRUPTION_CORRUPTIONABILITY = 34
    CORRUPTION_CANCEL = 35
    BEHAVIOR_HOLDFIREON_GHOST = 36
    BEHAVIOR_HOLDFIREOFF_GHOST = 38
    MORPHTOINFESTEDTERRAN_INFESTEDTERRANS = 40
    EXPLODE_EXPLODE = 42
    RESEARCH_INTERCEPTORGRAVITONCATAPULT = 44
    FLEETBEACONRESEARCH_RESEARCHINTERCEPTORLAUNCHSPEEDUPGRADE = 45
    RESEARCH_PHOENIXANIONPULSECRYSTALS = 46
    FLEETBEACONRESEARCH_TEMPESTRANGEUPGRADE = 47
    FLEETBEACONRESEARCH_RESEARCHVOIDRAYSPEEDUPGRADE = 48
    FLEETBEACONRESEARCH_TEMPESTRESEARCHGROUNDATTACKUPGRADE = 49
    FUNGALGROWTH_FUNGALGROWTH = 74
    GUARDIANSHIELD_GUARDIANSHIELD = 76
    EFFECT_REPAIR_MULE = 78
    MORPHZERGLINGTOBANELING_BANELING = 80
    NEXUSTRAINMOTHERSHIP_MOTHERSHIP = 110
    FEEDBACK_FEEDBACK = 140
    EFFECT_MASSRECALL_STRATEGICRECALL = 142
    PLACEPOINTDEFENSEDRONE_POINTDEFENSEDRONE = 144
    HALLUCINATION_ARCHON = 146
    HALLUCINATION_COLOSSUS = 148
    HALLUCINATION_HIGHTEMPLAR = 150
    HALLUCINATION_IMMORTAL = 152
    HALLUCINATION_PHOENIX = 154
    HALLUCINATION_PROBE = 156
    HALLUCINATION_STALKER = 158
    HALLUCINATION_VOIDRAY = 160
    HALLUCINATION_WARPPRISM = 162
    HALLUCINATION_ZEALOT = 164
    HARVEST_GATHER_MULE = 166
    HARVEST_RETURN_MULE = 167
    SEEKERMISSILE_HUNTERSEEKERMISSILE = 169
    CALLDOWNMULE_CALLDOWNMULE = 171
    GRAVITONBEAM_GRAVITONBEAM = 173
    CANCEL_GRAVITONBEAM = 174
    BUILDINPROGRESSNYDUSCANAL_CANCEL = 175
    SIPHON_SIPHON = 177
    SIPHON_CANCEL = 178
    LEECH_LEECH = 179
    SPAWNCHANGELING_SPAWNCHANGELING = 181
    DISGUISEASZEALOT_ZEALOT = 183
    DISGUISEASMARINEWITHSHIELD_MARINE = 185
    DISGUISEASMARINEWITHOUTSHIELD_MARINE = 187
    DISGUISEASZERGLINGWITHWINGS_ZERGLING = 189
    DISGUISEASZERGLINGWITHOUTWINGS_ZERGLING = 191
    PHASESHIFT_PHASESHIFT = 193
    RALLY_BUILDING = 195
    RALLY_MORPHING_UNIT = 199
    RALLY_COMMANDCENTER = 203
    RALLY_NEXUS = 207
    RALLY_HATCHERY_UNITS = 211
    RALLY_HATCHERY_WORKERS = 212
    RESEARCH_GLIALREGENERATION = 216
    RESEARCH_TUNNELINGCLAWS = 217
    ROACHWARRENRESEARCH_ROACHSUPPLY = 218
    SAPSTRUCTURE_SAPSTRUCTURE = 245
    INFESTEDTERRANS_INFESTEDTERRANS = 247
    NEURALPARASITE_NEURALPARASITE = 249
    CANCEL_NEURALPARASITE = 250
    EFFECT_INJECTLARVA = 251
    EFFECT_STIM_MARAUDER = 253
    SUPPLYDROP_SUPPLYDROP = 255
    _250MMSTRIKECANNONS_250MMSTRIKECANNONS = 257
    _250MMSTRIKECANNONS_CANCEL = 258
    TEMPORALRIFT_TEMPORALRIFT = 259
    EFFECT_CHRONOBOOST = 261
    RESEARCH_ANABOLICSYNTHESIS = 263
    RESEARCH_CHITINOUSPLATING = 265
    WORMHOLETRANSIT_WORMHOLETRANSIT = 293
    HARVEST_GATHER_SCV = 295
    HARVEST_RETURN_SCV = 296
    HARVEST_GATHER_PROBE = 298
    HARVEST_RETURN_PROBE = 299
    ATTACKWARPPRISM_ATTACKWARPPRISM = 301
    ATTACKWARPPRISM_ATTACKTOWARDS = 302
    ATTACKWARPPRISM_ATTACKBARRAGE = 303
    CANCEL_QUEUE1 = 304
    CANCELSLOT_QUEUE1 = 305
    CANCEL_QUEUE5 = 306
    CANCELSLOT_QUEUE5 = 307
    CANCEL_QUEUECANCELTOSELECTION = 308
    CANCELSLOT_QUEUECANCELTOSELECTION = 309
    QUE5LONGBLEND_CANCEL = 310
    QUE5LONGBLEND_CANCELSLOT = 311
    CANCEL_QUEUEADDON = 312
    CANCELSLOT_ADDON = 313
    CANCEL_BUILDINPROGRESS = 314
    HALT_BUILDING = 315
    EFFECT_REPAIR_SCV = 316
    TERRANBUILD_COMMANDCENTER = 318
    TERRANBUILD_SUPPLYDEPOT = 319
    TERRANBUILD_REFINERY = 320
    TERRANBUILD_BARRACKS = 321
    TERRANBUILD_ENGINEERINGBAY = 322
    TERRANBUILD_MISSILETURRET = 323
    TERRANBUILD_BUNKER = 324
    TERRANBUILD_SENSORTOWER = 326
    TERRANBUILD_GHOSTACADEMY = 327
    TERRANBUILD_FACTORY = 328
    TERRANBUILD_STARPORT = 329
    TERRANBUILD_ARMORY = 331
    TERRANBUILD_FUSIONCORE = 333
    HALT_TERRANBUILD = 348
    RAVENBUILD_AUTOTURRET = 349
    RAVENBUILD_CANCEL = 379
    EFFECT_STIM_MARINE = 380
    BEHAVIOR_CLOAKON_GHOST = 382
    BEHAVIOR_CLOAKOFF_GHOST = 383
    SNIPE_SNIPE = 384
    MEDIVACHEAL_HEAL = 386
    SIEGEMODE_SIEGEMODE = 388
    UNSIEGE_UNSIEGE = 390
    BEHAVIOR_CLOAKON_BANSHEE = 392
    BEHAVIOR_CLOAKOFF_BANSHEE = 393
    LOAD_MEDIVAC = 394
    UNLOADALLAT_MEDIVAC = 396
    UNLOADUNIT_MEDIVAC = 397
    SCANNERSWEEP_SCAN = 399
    YAMATO_YAMATOGUN = 401
    MORPH_VIKINGASSAULTMODE = 403
    MORPH_VIKINGFIGHTERMODE = 405
    LOAD_BUNKER = 407
    UNLOADALL_BUNKER = 408
    UNLOADUNIT_BUNKER = 410
    UNLOADALL_COMMANDCENTER = 413
    UNLOADUNIT_COMMANDCENTER = 415
    LOADALL_COMMANDCENTER = 416
    LIFT_COMMANDCENTER = 417
    LAND_COMMANDCENTER = 419
    BUILD_TECHLAB_BARRACKS = 421
    BUILD_REACTOR_BARRACKS = 422
    CANCEL_BARRACKSADDON = 451
    LIFT_BARRACKS = 452
    BUILD_TECHLAB_FACTORY = 454
    BUILD_REACTOR_FACTORY = 455
    CANCEL_FACTORYADDON = 484
    LIFT_FACTORY = 485
    BUILD_TECHLAB_STARPORT = 487
    BUILD_REACTOR_STARPORT = 488
    CANCEL_STARPORTADDON = 517
    LIFT_STARPORT = 518
    LAND_FACTORY = 520
    LAND_STARPORT = 522
    COMMANDCENTERTRAIN_SCV = 524
    LAND_BARRACKS = 554
    MORPH_SUPPLYDEPOT_LOWER = 556
    MORPH_SUPPLYDEPOT_RAISE = 558
    BARRACKSTRAIN_MARINE = 560
    BARRACKSTRAIN_REAPER = 561
    BARRACKSTRAIN_GHOST = 562
    BARRACKSTRAIN_MARAUDER = 563
    FACTORYTRAIN_SIEGETANK = 591
    FACTORYTRAIN_THOR = 594
    FACTORYTRAIN_HELLION = 595
    TRAIN_HELLBAT = 596
    TRAIN_CYCLONE = 597
    FACTORYTRAIN_WIDOWMINE = 614
    STARPORTTRAIN_MEDIVAC = 620
    STARPORTTRAIN_BANSHEE = 621
    STARPORTTRAIN_RAVEN = 622
    STARPORTTRAIN_BATTLECRUISER = 623
    STARPORTTRAIN_VIKINGFIGHTER = 624
    STARPORTTRAIN_LIBERATOR = 626
    RESEARCH_HISECAUTOTRACKING = 650
    RESEARCH_TERRANSTRUCTUREARMORUPGRADE = 651
    ENGINEERINGBAYRESEARCH_TERRANINFANTRYWEAPONSLEVEL1 = 652
    ENGINEERINGBAYRESEARCH_TERRANINFANTRYWEAPONSLEVEL2 = 653
    ENGINEERINGBAYRESEARCH_TERRANINFANTRYWEAPONSLEVEL3 = 654
    RESEARCH_NEOSTEELFRAME = 655
    ENGINEERINGBAYRESEARCH_TERRANINFANTRYARMORLEVEL1 = 656
    ENGINEERINGBAYRESEARCH_TERRANINFANTRYARMORLEVEL2 = 657
    ENGINEERINGBAYRESEARCH_TERRANINFANTRYARMORLEVEL3 = 658
    MERCCOMPOUNDRESEARCH_REAPERSPEED = 683
    BUILD_NUKE = 710
    BARRACKSTECHLABRESEARCH_STIMPACK = 730
    RESEARCH_COMBATSHIELD = 731
    RESEARCH_CONCUSSIVESHELLS = 732
    RESEARCH_INFERNALPREIGNITER = 761
    FACTORYTECHLABRESEARCH_RESEARCHTRANSFORMATIONSERVOS = 763
    RESEARCH_DRILLINGCLAWS = 764
    FACTORYTECHLABRESEARCH_RESEARCHLOCKONRANGEUPGRADE = 765
    RESEARCH_SMARTSERVOS = 766
    FACTORYTECHLABRESEARCH_RESEARCHARMORPIERCINGROCKETS = 767
    RESEARCH_CYCLONERAPIDFIRELAUNCHERS = 768
    RESEARCH_CYCLONELOCKONDAMAGE = 769
    RESEARCH_BANSHEECLOAKINGFIELD = 790
    STARPORTTECHLABRESEARCH_RESEARCHMEDIVACENERGYUPGRADE = 792
    RESEARCH_RAVENCORVIDREACTOR = 793
    STARPORTTECHLABRESEARCH_RESEARCHSEEKERMISSILE = 796
    STARPORTTECHLABRESEARCH_RESEARCHDURABLEMATERIALS = 797
    RESEARCH_BANSHEEHYPERFLIGHTROTORS = 799
    STARPORTTECHLABRESEARCH_RESEARCHLIBERATORAGMODE = 800
    STARPORTTECHLABRESEARCH_RESEARCHRAPIDDEPLOYMENT = 802
    RESEARCH_RAVENRECALIBRATEDEXPLOSIVES = 803
    RESEARCH_HIGHCAPACITYFUELTANKS = 804
    RESEARCH_ADVANCEDBALLISTICS = 805
    STARPORTTECHLABRESEARCH_RAVENRESEARCHENHANCEDMUNITIONS = 806
    RESEARCH_PERSONALCLOAKING = 820
    GHOSTACADEMYRESEARCH_RESEARCHGHOSTENERGYUPGRADE = 821
    GHOSTACADEMYRESEARCH_RESEARCHENHANCEDSHOCKWAVES = 822
    ARMORYRESEARCH_TERRANVEHICLEPLATINGLEVEL1 = 852
    ARMORYRESEARCH_TERRANVEHICLEPLATINGLEVEL2 = 853
    ARMORYRESEARCH_TERRANVEHICLEPLATINGLEVEL3 = 854
    ARMORYRESEARCH_TERRANVEHICLEWEAPONSLEVEL1 = 855
    ARMORYRESEARCH_TERRANVEHICLEWEAPONSLEVEL2 = 856
    ARMORYRESEARCH_TERRANVEHICLEWEAPONSLEVEL3 = 857
    ARMORYRESEARCH_TERRANSHIPPLATINGLEVEL1 = 858
    ARMORYRESEARCH_TERRANSHIPPLATINGLEVEL2 = 859
    ARMORYRESEARCH_TERRANSHIPPLATINGLEVEL3 = 860
    ARMORYRESEARCH_TERRANSHIPWEAPONSLEVEL1 = 861
    ARMORYRESEARCH_TERRANSHIPWEAPONSLEVEL2 = 862
    ARMORYRESEARCH_TERRANSHIPWEAPONSLEVEL3 = 863
    ARMORYRESEARCH_TERRANVEHICLEANDSHIPPLATINGLEVEL1 = 864
    ARMORYRESEARCH_TERRANVEHICLEANDSHIPPLATINGLEVEL2 = 865
    ARMORYRESEARCH_TERRANVEHICLEANDSHIPPLATINGLEVEL3 = 866
    PROTOSSBUILD_NEXUS = 880
    PROTOSSBUILD_PYLON = 881
    PROTOSSBUILD_ASSIMILATOR = 882
    PROTOSSBUILD_GATEWAY = 883
    PROTOSSBUILD_FORGE = 884
    PROTOSSBUILD_FLEETBEACON = 885
    PROTOSSBUILD_TWILIGHTCOUNCIL = 886
    PROTOSSBUILD_PHOTONCANNON = 887
    PROTOSSBUILD_STARGATE = 889
    PROTOSSBUILD_TEMPLARARCHIVE = 890
    PROTOSSBUILD_DARKSHRINE = 891
    PROTOSSBUILD_ROBOTICSBAY = 892
    PROTOSSBUILD_ROBOTICSFACILITY = 893
    PROTOSSBUILD_CYBERNETICSCORE = 894
    BUILD_SHIELDBATTERY = 895
    PROTOSSBUILD_CANCEL = 910
    LOAD_WARPPRISM = 911
    UNLOADALL_WARPPRISM = 912
    UNLOADALLAT_WARPPRISM = 913
    UNLOADUNIT_WARPPRISM = 914
    GATEWAYTRAIN_ZEALOT = 916
    GATEWAYTRAIN_STALKER = 917
    GATEWAYTRAIN_HIGHTEMPLAR = 919
    GATEWAYTRAIN_DARKTEMPLAR = 920
    GATEWAYTRAIN_SENTRY = 921
    TRAIN_ADEPT = 922
    STARGATETRAIN_PHOENIX = 946
    STARGATETRAIN_CARRIER = 948
    STARGATETRAIN_VOIDRAY = 950
    STARGATETRAIN_ORACLE = 954
    STARGATETRAIN_TEMPEST = 955
    ROBOTICSFACILITYTRAIN_WARPPRISM = 976
    ROBOTICSFACILITYTRAIN_OBSERVER = 977
    ROBOTICSFACILITYTRAIN_COLOSSUS = 978
    ROBOTICSFACILITYTRAIN_IMMORTAL = 979
    TRAIN_DISRUPTOR = 994
    NEXUSTRAIN_PROBE = 1006
    PSISTORM_PSISTORM = 1036
    CANCEL_HANGARQUEUE5 = 1038
    CANCELSLOT_HANGARQUEUE5 = 1039
    BROODLORDQUEUE2_CANCEL = 1040
    BROODLORDQUEUE2_CANCELSLOT = 1041
    BUILD_INTERCEPTORS = 1042
    FORGERESEARCH_PROTOSSGROUNDWEAPONSLEVEL1 = 1062
    FORGERESEARCH_PROTOSSGROUNDWEAPONSLEVEL2 = 1063
    FORGERESEARCH_PROTOSSGROUNDWEAPONSLEVEL3 = 1064
    FORGERESEARCH_PROTOSSGROUNDARMORLEVEL1 = 1065
    FORGERESEARCH_PROTOSSGROUNDARMORLEVEL2 = 1066
    FORGERESEARCH_PROTOSSGROUNDARMORLEVEL3 = 1067
    FORGERESEARCH_PROTOSSSHIELDSLEVEL1 = 1068
    FORGERESEARCH_PROTOSSSHIELDSLEVEL2 = 1069
    FORGERESEARCH_PROTOSSSHIELDSLEVEL3 = 1070
    RESEARCH_GRAVITICBOOSTER = 1093
    RESEARCH_GRAVITICDRIVE = 1094
    RESEARCH_EXTENDEDTHERMALLANCE = 1097
    ROBOTICSBAYRESEARCH_RESEARCHIMMORTALREVIVE = 1099
    RESEARCH_PSISTORM = 1126
    ZERGBUILD_HATCHERY = 1152
    ZERGBUILD_CREEPTUMOR = 1153
    ZERGBUILD_EXTRACTOR = 1154
    ZERGBUILD_SPAWNINGPOOL = 1155
    ZERGBUILD_EVOLUTIONCHAMBER = 1156
    ZERGBUILD_HYDRALISKDEN = 1157
    ZERGBUILD_SPIRE = 1158
    ZERGBUILD_ULTRALISKCAVERN = 1159
    ZERGBUILD_INFESTATIONPIT = 1160
    ZERGBUILD_NYDUSNETWORK = 1161
    ZERGBUILD_BANELINGNEST = 1162
    BUILD_LURKERDEN = 1163
    ZERGBUILD_ROACHWARREN = 1165
    ZERGBUILD_SPINECRAWLER = 1166
    ZERGBUILD_SPORECRAWLER = 1167
    ZERGBUILD_CANCEL = 1182
    HARVEST_GATHER_DRONE = 1183
    HARVEST_RETURN_DRONE = 1184
    RESEARCH_ZERGMELEEWEAPONSLEVEL1 = 1186
    RESEARCH_ZERGMELEEWEAPONSLEVEL2 = 1187
    RESEARCH_ZERGMELEEWEAPONSLEVEL3 = 1188
    RESEARCH_ZERGGROUNDARMORLEVEL1 = 1189
    RESEARCH_ZERGGROUNDARMORLEVEL2 = 1190
    RESEARCH_ZERGGROUNDARMORLEVEL3 = 1191
    RESEARCH_ZERGMISSILEWEAPONSLEVEL1 = 1192
    RESEARCH_ZERGMISSILEWEAPONSLEVEL2 = 1193
    RESEARCH_ZERGMISSILEWEAPONSLEVEL3 = 1194
    EVOLUTIONCHAMBERRESEARCH_EVOLVEPROPULSIVEPERISTALSIS = 1195
    UPGRADETOLAIR_LAIR = 1216
    CANCEL_MORPHLAIR = 1217
    UPGRADETOHIVE_HIVE = 1218
    CANCEL_MORPHHIVE = 1219
    UPGRADETOGREATERSPIRE_GREATERSPIRE = 1220
    CANCEL_MORPHGREATERSPIRE = 1221
    RESEARCH_PNEUMATIZEDCARAPACE = 1223
    LAIRRESEARCH_EVOLVEVENTRALSACKS = 1224
    RESEARCH_BURROW = 1225
    RESEARCH_ZERGLINGADRENALGLANDS = 1252
    RESEARCH_ZERGLINGMETABOLICBOOST = 1253
    RESEARCH_GROOVEDSPINES = 1282
    RESEARCH_MUSCULARAUGMENTS = 1283
    HYDRALISKDENRESEARCH_RESEARCHLURKERRANGE = 1286
    RESEARCH_ZERGFLYERATTACKLEVEL1 = 1312
    RESEARCH_ZERGFLYERATTACKLEVEL2 = 1313
    RESEARCH_ZERGFLYERATTACKLEVEL3 = 1314
    RESEARCH_ZERGFLYERARMORLEVEL1 = 1315
    RESEARCH_ZERGFLYERARMORLEVEL2 = 1316
    RESEARCH_ZERGFLYERARMORLEVEL3 = 1317
    LARVATRAIN_DRONE = 1342
    LARVATRAIN_ZERGLING = 1343
    LARVATRAIN_OVERLORD = 1344
    LARVATRAIN_HYDRALISK = 1345
    LARVATRAIN_MUTALISK = 1346
    LARVATRAIN_ULTRALISK = 1348
    LARVATRAIN_ROACH = 1351
    LARVATRAIN_INFESTOR = 1352
    LARVATRAIN_CORRUPTOR = 1353
    LARVATRAIN_VIPER = 1354
    TRAIN_SWARMHOST = 1356
    MORPHTOBROODLORD_BROODLORD = 1372
    CANCEL_MORPHBROODLORD = 1373
    BURROWDOWN_BANELING = 1374
    BURROWBANELINGDOWN_CANCEL = 1375
    BURROWUP_BANELING = 1376
    BURROWDOWN_DRONE = 1378
    BURROWDRONEDOWN_CANCEL = 1379
    BURROWUP_DRONE = 1380
    BURROWDOWN_HYDRALISK = 1382
    BURROWHYDRALISKDOWN_CANCEL = 1383
    BURROWUP_HYDRALISK = 1384
    BURROWDOWN_ROACH = 1386
    BURROWROACHDOWN_CANCEL = 1387
    BURROWUP_ROACH = 1388
    BURROWDOWN_ZERGLING = 1390
    BURROWZERGLINGDOWN_CANCEL = 1391
    BURROWUP_ZERGLING = 1392
    BURROWDOWN_INFESTORTERRAN = 1394
    BURROWUP_INFESTORTERRAN = 1396
    REDSTONELAVACRITTERBURROW_BURROWDOWN = 1398
    REDSTONELAVACRITTERINJUREDBURROW_BURROWDOWN = 1400
    REDSTONELAVACRITTERUNBURROW_BURROWUP = 1402
    REDSTONELAVACRITTERINJUREDUNBURROW_BURROWUP = 1404
    LOAD_OVERLORD = 1406
    UNLOADALLAT_OVERLORD = 1408
    UNLOADUNIT_OVERLORD = 1409
    MERGEABLE_CANCEL = 1411
    WARPABLE_CANCEL = 1412
    WARPGATETRAIN_ZEALOT = 1413
    WARPGATETRAIN_STALKER = 1414
    WARPGATETRAIN_HIGHTEMPLAR = 1416
    WARPGATETRAIN_DARKTEMPLAR = 1417
    WARPGATETRAIN_SENTRY = 1418
    TRAINWARP_ADEPT = 1419
    BURROWDOWN_QUEEN = 1433
    BURROWQUEENDOWN_CANCEL = 1434
    BURROWUP_QUEEN = 1435
    LOAD_NYDUSNETWORK = 1437
    UNLOADALL_NYDASNETWORK = 1438
    UNLOADUNIT_NYDASNETWORK = 1440
    EFFECT_BLINK_STALKER = 1442
    BURROWDOWN_INFESTOR = 1444
    BURROWINFESTORDOWN_CANCEL = 1445
    BURROWUP_INFESTOR = 1446
    MORPH_OVERSEER = 1448
    CANCEL_MORPHOVERSEER = 1449
    UPGRADETOPLANETARYFORTRESS_PLANETARYFORTRESS = 1450
    CANCEL_MORPHPLANETARYFORTRESS = 1451
    RESEARCH_PATHOGENGLANDS = 1454
    RESEARCH_NEURALPARASITE = 1455
    INFESTATIONPITRESEARCH_RESEARCHLOCUSTLIFETIMEINCREASE = 1456
    INFESTATIONPITRESEARCH_EVOLVEAMORPHOUSARMORCLOUD = 1457
    RESEARCH_CENTRIFUGALHOOKS = 1482
    BURROWDOWN_ULTRALISK = 1512
    BURROWUP_ULTRALISK = 1514
    UPGRADETOORBITAL_ORBITALCOMMAND = 1516
    CANCEL_MORPHORBITAL = 1517
    MORPH_WARPGATE = 1518
    UPGRADETOWARPGATE_CANCEL = 1519
    MORPH_GATEWAY = 1520
    MORPHBACKTOGATEWAY_CANCEL = 1521
    LIFT_ORBITALCOMMAND = 1522
    LAND_ORBITALCOMMAND = 1524
    FORCEFIELD_FORCEFIELD = 1526
    FORCEFIELD_CANCEL = 1527
    MORPH_WARPPRISMPHASINGMODE = 1528
    PHASINGMODE_CANCEL = 1529
    MORPH_WARPPRISMTRANSPORTMODE = 1530
    TRANSPORTMODE_CANCEL = 1531
    RESEARCH_BATTLECRUISERWEAPONREFIT = 1532
    FUSIONCORERESEARCH_RESEARCHBALLISTICRANGE = 1533
    FUSIONCORERESEARCH_RESEARCHRAPIDREIGNITIONSYSTEM = 1534
    CYBERNETICSCORERESEARCH_PROTOSSAIRWEAPONSLEVEL1 = 1562
    CYBERNETICSCORERESEARCH_PROTOSSAIRWEAPONSLEVEL2 = 1563
    CYBERNETICSCORERESEARCH_PROTOSSAIRWEAPONSLEVEL3 = 1564
    CYBERNETICSCORERESEARCH_PROTOSSAIRARMORLEVEL1 = 1565
    CYBERNETICSCORERESEARCH_PROTOSSAIRARMORLEVEL2 = 1566
    CYBERNETICSCORERESEARCH_PROTOSSAIRARMORLEVEL3 = 1567
    RESEARCH_WARPGATE = 1568
    CYBERNETICSCORERESEARCH_RESEARCHHALLUCINATION = 1571
    RESEARCH_CHARGE = 1592
    RESEARCH_BLINK = 1593
    RESEARCH_ADEPTRESONATINGGLAIVES = 1594
    TWILIGHTCOUNCILRESEARCH_RESEARCHPSIONICSURGE = 1595
    TWILIGHTCOUNCILRESEARCH_RESEARCHAMPLIFIEDSHIELDING = 1596
    TWILIGHTCOUNCILRESEARCH_RESEARCHPSIONICAMPLIFIERS = 1597
    TACNUKESTRIKE_NUKECALLDOWN = 1622
    CANCEL_NUKE = 1623
    SALVAGEBUNKERREFUND_SALVAGE = 1624
    SALVAGEBUNKER_SALVAGE = 1626
    EMP_EMP = 1628
    VORTEX_VORTEX = 1630
    TRAINQUEEN_QUEEN = 1632
    BURROWCREEPTUMORDOWN_BURROWDOWN = 1662
    TRANSFUSION_TRANSFUSION = 1664
    BARRACKSTECHLABMORPH_TECHLABBARRACKS = 1668
    FACTORYTECHLABMORPH_TECHLABFACTORY = 1670
    STARPORTTECHLABMORPH_TECHLABSTARPORT = 1672
    BARRACKSREACTORMORPH_REACTOR = 1676
    FACTORYREACTORMORPH_REACTOR = 1678
    STARPORTREACTORMORPH_REACTOR = 1680
    ATTACK_REDIRECT = 1682
    EFFECT_STIM_MARINE_REDIRECT = 1683
    EFFECT_STIM_MARAUDER_REDIRECT = 1684
    BURROWEDSTOP_STOPROACHBURROWED = 1685
    BURROWEDSTOP_HOLDFIRESPECIAL = 1686
    STOP_REDIRECT = 1691
    BEHAVIOR_GENERATECREEPON = 1692
    BEHAVIOR_GENERATECREEPOFF = 1693
    BUILD_CREEPTUMOR_QUEEN = 1694
    QUEENBUILD_CANCEL = 1724
    SPINECRAWLERUPROOT_SPINECRAWLERUPROOT = 1725
    SPINECRAWLERUPROOT_CANCEL = 1726
    SPORECRAWLERUPROOT_SPORECRAWLERUPROOT = 1727
    SPORECRAWLERUPROOT_CANCEL = 1728
    SPINECRAWLERROOT_SPINECRAWLERROOT = 1729
    CANCEL_SPINECRAWLERROOT = 1730
    SPORECRAWLERROOT_SPORECRAWLERROOT = 1731
    CANCEL_SPORECRAWLERROOT = 1732
    BUILD_CREEPTUMOR_TUMOR = 1733
    CANCEL_CREEPTUMOR = 1763
    BUILDAUTOTURRET_AUTOTURRET = 1764
    MORPH_ARCHON = 1766
    ARCHON_WARP_TARGET = 1767
    BUILD_NYDUSWORM = 1768
    BUILDNYDUSCANAL_SUMMONNYDUSCANALATTACKER = 1769
    BUILDNYDUSCANAL_CANCEL = 1798
    EFFECT_CHARGE = 1819
    HERDINTERACT_HERD = 1821
    FRENZY_FRENZY = 1823
    CONTAMINATE_CONTAMINATE = 1825
    INFESTEDTERRANSLAYEGG_INFESTEDTERRANS = 1829
    CANCEL_QUEUEPASIVE = 1831
    CANCELSLOT_QUEUEPASSIVE = 1832
    CANCEL_QUEUEPASSIVECANCELTOSELECTION = 1833
    CANCELSLOT_QUEUEPASSIVECANCELTOSELECTION = 1834
    MORPHTOGHOSTALTERNATE_MOVE = 1835
    MORPHTOGHOSTNOVA_MOVE = 1837
    DIGESTERCREEPSPRAY_DIGESTERCREEPSPRAY = 1839
    MORPHTOCOLLAPSIBLETERRANTOWERDEBRIS_CANCEL = 1842
    MORPHTOCOLLAPSIBLETERRANTOWERDEBRISRAMPLEFT_CANCEL = 1844
    MORPHTOCOLLAPSIBLETERRANTOWERDEBRISRAMPRIGHT_CANCEL = 1846
    MORPH_MOTHERSHIP = 1847
    CANCEL_MORPHMOTHERSHIP = 1848
    MOTHERSHIPSTASIS_MOTHERSHIPSTASIS = 1849
    CANCEL_MOTHERSHIPSTASIS = 1850
    MOTHERSHIPCOREWEAPON_MOTHERSHIPSTASIS = 1851
    NEXUSTRAINMOTHERSHIPCORE_MOTHERSHIPCORE = 1853
    MOTHERSHIPCORETELEPORT_MOTHERSHIPCORETELEPORT = 1883
    SALVAGEDRONEREFUND_SALVAGE = 1885
    SALVAGEDRONE_SALVAGE = 1887
    SALVAGEZERGLINGREFUND_SALVAGE = 1889
    SALVAGEZERGLING_SALVAGE = 1891
    SALVAGEQUEENREFUND_SALVAGE = 1893
    SALVAGEQUEEN_SALVAGE = 1895
    SALVAGEROACHREFUND_SALVAGE = 1897
    SALVAGEROACH_SALVAGE = 1899
    SALVAGEBANELINGREFUND_SALVAGE = 1901
    SALVAGEBANELING_SALVAGE = 1903
    SALVAGEHYDRALISKREFUND_SALVAGE = 1905
    SALVAGEHYDRALISK_SALVAGE = 1907
    SALVAGEINFESTORREFUND_SALVAGE = 1909
    SALVAGEINFESTOR_SALVAGE = 1911
    SALVAGESWARMHOSTREFUND_SALVAGE = 1913
    SALVAGESWARMHOST_SALVAGE = 1915
    SALVAGEULTRALISKREFUND_SALVAGE = 1917
    SALVAGEULTRALISK_SALVAGE = 1919
    DIGESTERTRANSPORT_LOADDIGESTER = 1921
    SPECTRESHIELD_SPECTRESHIELD = 1926
    XELNAGAHEALINGSHRINE_XELNAGAHEALINGSHRINE = 1928
    NEXUSINVULNERABILITY_NEXUSINVULNERABILITY = 1930
    NEXUSPHASESHIFT_NEXUSPHASESHIFT = 1932
    SPAWNCHANGELINGTARGET_SPAWNCHANGELING = 1934
    QUEENLAND_QUEENLAND = 1936
    QUEENFLY_QUEENFLY = 1938
    ORACLECLOAKFIELD_ORACLECLOAKFIELD = 1940
    FLYERSHIELD_FLYERSHIELD = 1942
    LOCUSTTRAIN_SWARMHOST = 1944
    EFFECT_MASSRECALL_MOTHERSHIPCORE = 1974
    SINGLERECALL_SINGLERECALL = 1976
    MORPH_HELLION = 1978
    RESTORESHIELDS_RESTORESHIELDS = 1980
    SCRYER_SCRYER = 1982
    LEECHRESOURCES_CANCEL = 1987
    SNIPEDOT_SNIPEDOT = 1988
    SWARMHOSTSPAWNLOCUSTS_LOCUSTMP = 1990
    CLONE_CLONE = 1992
    BUILDINGSHIELD_BUILDINGSHIELD = 1994
    MORPHTOCOLLAPSIBLEROCKTOWERDEBRIS_CANCEL = 1997
    MORPH_HELLBAT = 1998
    BUILDINGSTASIS_BUILDINGSTASIS = 2000
    MAXIUMTHRUST_MAXIMUMTHRUST = 2006
    BURROWDOWN_SWARMHOST = 2014
    MORPHTOSWARMHOSTBURROWEDMP_CANCEL = 2015
    BURROWUP_SWARMHOST = 2016
    SPAWNINFESTEDTERRAN_LOCUSTMP = 2018
    ATTACKPROTOSSBUILDING_ATTACKBUILDING = 2048
    ATTACKPROTOSSBUILDING_ATTACKTOWARDS = 2049
    ATTACKPROTOSSBUILDING_ATTACKBARRAGE = 2050
    BURROWEDBANELINGSTOP_STOPROACHBURROWED = 2051
    BURROWEDBANELINGSTOP_HOLDFIRESPECIAL = 2052
    STOP_BUILDING = 2057
    STOPPROTOSSBUILDING_HOLDFIRE = 2058
    STOPPROTOSSBUILDING_CHEER = 2059
    STOPPROTOSSBUILDING_DANCE = 2060
    BLINDINGCLOUD_BLINDINGCLOUD = 2063
    EYESTALK_EYESTALK = 2065
    EYESTALK_CANCEL = 2066
    EFFECT_ABDUCT = 2067
    VIPERCONSUME_VIPERCONSUME = 2069
    VIPERCONSUMEMINERALS_VIPERCONSUME = 2071
    VIPERCONSUMESTRUCTURE_VIPERCONSUME = 2073
    CANCEL_PROTOSSBUILDINGQUEUE = 2075
    PROTOSSBUILDINGQUEUE_CANCELSLOT = 2076
    QUE8_CANCEL = 2077
    QUE8_CANCELSLOT = 2078
    TESTZERG_CANCEL = 2080
    BEHAVIOR_BUILDINGATTACKON = 2081
    BEHAVIOR_BUILDINGATTACKOFF = 2082
    PICKUPSCRAPSMALL_PICKUPSCRAPSMALL = 2083
    PICKUPSCRAPMEDIUM_PICKUPSCRAPMEDIUM = 2085
    PICKUPSCRAPLARGE_PICKUPSCRAPLARGE = 2087
    PICKUPPALLETGAS_PICKUPPALLETGAS = 2089
    PICKUPPALLETMINERALS_PICKUPPALLETMINERALS = 2091
    MASSIVEKNOCKOVER_MASSIVEKNOCKOVER = 2093
    BURROWDOWN_WIDOWMINE = 2095
    WIDOWMINEBURROW_CANCEL = 2096
    BURROWUP_WIDOWMINE = 2097
    WIDOWMINEATTACK_WIDOWMINEATTACK = 2099
    TORNADOMISSILE_TORNADOMISSILE = 2101
    MOTHERSHIPCOREENERGIZE_MOTHERSHIPCOREENERGIZE = 2102
    MOTHERSHIPCOREENERGIZE_CANCEL = 2103
    LURKERASPECTMPFROMHYDRALISKBURROWED_LURKERMPFROMHYDRALISKBURROWED = 2104
    LURKERASPECTMPFROMHYDRALISKBURROWED_CANCEL = 2105
    LURKERASPECTMP_LURKERMP = 2106
    LURKERASPECTMP_CANCEL = 2107
    BURROWDOWN_LURKER = 2108
    BURROWLURKERMPDOWN_CANCEL = 2109
    BURROWUP_LURKER = 2110
    MORPH_LURKERDEN = 2112
    CANCEL_MORPHLURKERDEN = 2113
    HALLUCINATION_ORACLE = 2114
    EFFECT_MEDIVACIGNITEAFTERBURNERS = 2116
    EXTENDINGBRIDGENEWIDE8OUT_BRIDGEEXTEND = 2118
    EXTENDINGBRIDGENEWIDE8_BRIDGERETRACT = 2120
    EXTENDINGBRIDGENWWIDE8OUT_BRIDGEEXTEND = 2122
    EXTENDINGBRIDGENWWIDE8_BRIDGERETRACT = 2124
    EXTENDINGBRIDGENEWIDE10OUT_BRIDGEEXTEND = 2126
    EXTENDINGBRIDGENEWIDE10_BRIDGERETRACT = 2128
    EXTENDINGBRIDGENWWIDE10OUT_BRIDGEEXTEND = 2130
    EXTENDINGBRIDGENWWIDE10_BRIDGERETRACT = 2132
    EXTENDINGBRIDGENEWIDE12OUT_BRIDGEEXTEND = 2134
    EXTENDINGBRIDGENEWIDE12_BRIDGERETRACT = 2136
    EXTENDINGBRIDGENWWIDE12OUT_BRIDGEEXTEND = 2138
    EXTENDINGBRIDGENWWIDE12_BRIDGERETRACT = 2140
    INVULNERABILITYSHIELD_INVULNERABILITYSHIELD = 2142
    CRITTERFLEE_CRITTERFLEE = 2144
    ORACLEREVELATION_ORACLEREVELATION = 2146
    ORACLEREVELATIONMODE_ORACLEREVELATIONMODE = 2148
    ORACLEREVELATIONMODE_CANCEL = 2149
    ORACLENORMALMODE_ORACLENORMALMODE = 2150
    ORACLENORMALMODE_CANCEL = 2151
    MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPRIGHT_CANCEL = 2153
    MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPLEFT_CANCEL = 2155
    VOIDSIPHON_VOIDSIPHON = 2156
    ULTRALISKWEAPONCOOLDOWN_ULTRALISKWEAPONCOOLDOWN = 2158
    MOTHERSHIPCOREPURIFYNEXUSCANCEL_CANCEL = 2160
    EFFECT_PHOTONOVERCHARGE = 2162
    XELNAGA_CAVERNS_DOORE_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2164
    XELNAGA_CAVERNS_DOOREOPENED_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2166
    XELNAGA_CAVERNS_DOORN_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2168
    XELNAGA_CAVERNS_DOORNE_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2170
    XELNAGA_CAVERNS_DOORNEOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2172
    XELNAGA_CAVERNS_DOORNOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2174
    XELNAGA_CAVERNS_DOORNW_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2176
    XELNAGA_CAVERNS_DOORNWOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2178
    XELNAGA_CAVERNS_DOORS_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2180
    XELNAGA_CAVERNS_DOORSE_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2182
    XELNAGA_CAVERNS_DOORSEOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2184
    XELNAGA_CAVERNS_DOORSOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2186
    XELNAGA_CAVERNS_DOORSW_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2188
    XELNAGA_CAVERNS_DOORSWOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2190
    XELNAGA_CAVERNS_DOORW_XELNAGA_CAVERNS_DOORDEFAULTCLOSE = 2192
    XELNAGA_CAVERNS_DOORWOPENED_XELNAGA_CAVERNS_DOORDEFAULTOPEN = 2194
    XELNAGA_CAVERNS_FLOATING_BRIDGENE8OUT_BRIDGEEXTEND = 2196
    XELNAGA_CAVERNS_FLOATING_BRIDGENE8_BRIDGERETRACT = 2198
    XELNAGA_CAVERNS_FLOATING_BRIDGENW8OUT_BRIDGEEXTEND = 2200
    XELNAGA_CAVERNS_FLOATING_BRIDGENW8_BRIDGERETRACT = 2202
    XELNAGA_CAVERNS_FLOATING_BRIDGENE10OUT_BRIDGEEXTEND = 2204
    XELNAGA_CAVERNS_FLOATING_BRIDGENE10_BRIDGERETRACT = 2206
    XELNAGA_CAVERNS_FLOATING_BRIDGENW10OUT_BRIDGEEXTEND = 2208
    XELNAGA_CAVERNS_FLOATING_BRIDGENW10_BRIDGERETRACT = 2210
    XELNAGA_CAVERNS_FLOATING_BRIDGENE12OUT_BRIDGEEXTEND = 2212
    XELNAGA_CAVERNS_FLOATING_BRIDGENE12_BRIDGERETRACT = 2214
    XELNAGA_CAVERNS_FLOATING_BRIDGENW12OUT_BRIDGEEXTEND = 2216
    XELNAGA_CAVERNS_FLOATING_BRIDGENW12_BRIDGERETRACT = 2218
    XELNAGA_CAVERNS_FLOATING_BRIDGEH8OUT_BRIDGEEXTEND = 2220
    XELNAGA_CAVERNS_FLOATING_BRIDGEH8_BRIDGERETRACT = 2222
    XELNAGA_CAVERNS_FLOATING_BRIDGEV8OUT_BRIDGEEXTEND = 2224
    XELNAGA_CAVERNS_FLOATING_BRIDGEV8_BRIDGERETRACT = 2226
    XELNAGA_CAVERNS_FLOATING_BRIDGEH10OUT_BRIDGEEXTEND = 2228
    XELNAGA_CAVERNS_FLOATING_BRIDGEH10_BRIDGERETRACT = 2230
    XELNAGA_CAVERNS_FLOATING_BRIDGEV10OUT_BRIDGEEXTEND = 2232
    XELNAGA_CAVERNS_FLOATING_BRIDGEV10_BRIDGERETRACT = 2234
    XELNAGA_CAVERNS_FLOATING_BRIDGEH12OUT_BRIDGEEXTEND = 2236
    XELNAGA_CAVERNS_FLOATING_BRIDGEH12_BRIDGERETRACT = 2238
    XELNAGA_CAVERNS_FLOATING_BRIDGEV12OUT_BRIDGEEXTEND = 2240
    XELNAGA_CAVERNS_FLOATING_BRIDGEV12_BRIDGERETRACT = 2242
    EFFECT_TIMEWARP = 2244
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENESHORT8OUT_BRIDGEEXTEND = 2246
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENESHORT8_BRIDGERETRACT = 2248
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENWSHORT8OUT_BRIDGEEXTEND = 2250
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENWSHORT8_BRIDGERETRACT = 2252
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENESHORT10OUT_BRIDGEEXTEND = 2254
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENESHORT10_BRIDGERETRACT = 2256
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENWSHORT10OUT_BRIDGEEXTEND = 2258
    SNOWREFINERY_TERRAN_EXTENDINGBRIDGENWSHORT10_BRIDGERETRACT = 2260
    ARMORYRESEARCHSWARM_TERRANVEHICLEANDSHIPWEAPONSLEVEL1 = 2294
    ARMORYRESEARCHSWARM_TERRANVEHICLEANDSHIPWEAPONSLEVEL2 = 2295
    ARMORYRESEARCHSWARM_TERRANVEHICLEANDSHIPWEAPONSLEVEL3 = 2296
    ARMORYRESEARCHSWARM_TERRANVEHICLEANDSHIPPLATINGLEVEL1 = 2297
    ARMORYRESEARCHSWARM_TERRANVEHICLEANDSHIPPLATINGLEVEL2 = 2298
    ARMORYRESEARCHSWARM_TERRANVEHICLEANDSHIPPLATINGLEVEL3 = 2299
    CAUSTICSPRAY_CAUSTICSPRAY = 2324
    ORACLECLOAKINGFIELDTARGETED_ORACLECLOAKINGFIELDTARGETED = 2326
    EFFECT_IMMORTALBARRIER = 2328
    MORPHTORAVAGER_RAVAGER = 2330
    CANCEL_MORPHRAVAGER = 2331
    MORPH_LURKER = 2332
    CANCEL_MORPHLURKER = 2333
    ORACLEPHASESHIFT_ORACLEPHASESHIFT = 2334
    RELEASEINTERCEPTORS_RELEASEINTERCEPTORS = 2336
    EFFECT_CORROSIVEBILE = 2338
    BURROWDOWN_RAVAGER = 2340
    BURROWRAVAGERDOWN_CANCEL = 2341
    BURROWUP_RAVAGER = 2342
    PURIFICATIONNOVA_PURIFICATIONNOVA = 2344
    EFFECT_PURIFICATIONNOVA = 2346
    IMPALE_IMPALE = 2348
    LOCKON_LOCKON = 2350
    LOCKONAIR_LOCKONAIR = 2352
    CANCEL_LOCKON = 2354
    CORRUPTIONBOMB_CORRUPTIONBOMB = 2356
    CORRUPTIONBOMB_CANCEL = 2357
    EFFECT_TACTICALJUMP = 2358
    OVERCHARGE_OVERCHARGE = 2360
    MORPH_THORHIGHIMPACTMODE = 2362
    THORAPMODE_CANCEL = 2363
    MORPH_THOREXPLOSIVEMODE = 2364
    CANCEL_MORPHTHOREXPLOSIVEMODE = 2365
    LIGHTOFAIUR_LIGHTOFAIUR = 2366
    EFFECT_MASSRECALL_MOTHERSHIP = 2368
    LOAD_NYDUSWORM = 2370
    UNLOADALL_NYDUSWORM = 2371
    BEHAVIOR_PULSARBEAMON = 2375
    BEHAVIOR_PULSARBEAMOFF = 2376
    PULSARBEAM_RIPFIELD = 2377
    PULSARCANNON_PULSARCANNON = 2379
    VOIDSWARMHOSTSPAWNLOCUST_VOIDSWARMHOSTSPAWNLOCUST = 2381
    LOCUSTMPFLYINGMORPHTOGROUND_LOCUSTMPFLYINGSWOOP = 2383
    LOCUSTMPMORPHTOAIR_LOCUSTMPFLYINGSWOOP = 2385
    EFFECT_LOCUSTSWOOP = 2387
    HALLUCINATION_DISRUPTOR = 2389
    HALLUCINATION_ADEPT = 2391
    EFFECT_VOIDRAYPRISMATICALIGNMENT = 2393
    AIURLIGHTBRIDGENE8OUT_BRIDGEEXTEND = 2397
    AIURLIGHTBRIDGENE8_BRIDGERETRACT = 2399
    AIURLIGHTBRIDGENE10OUT_BRIDGEEXTEND = 2401
    AIURLIGHTBRIDGENE10_BRIDGERETRACT = 2403
    AIURLIGHTBRIDGENE12OUT_BRIDGEEXTEND = 2405
    AIURLIGHTBRIDGENE12_BRIDGERETRACT = 2407
    AIURLIGHTBRIDGENW8OUT_BRIDGEEXTEND = 2409
    AIURLIGHTBRIDGENW8_BRIDGERETRACT = 2411
    AIURLIGHTBRIDGENW10OUT_BRIDGEEXTEND = 2413
    AIURLIGHTBRIDGENW10_BRIDGERETRACT = 2415
    AIURLIGHTBRIDGENW12OUT_BRIDGEEXTEND = 2417
    AIURLIGHTBRIDGENW12_BRIDGERETRACT = 2419
    AIURTEMPLEBRIDGENE8OUT_BRIDGEEXTEND = 2421
    AIURTEMPLEBRIDGENE8_BRIDGERETRACT = 2423
    AIURTEMPLEBRIDGENE10OUT_BRIDGEEXTEND = 2425
    AIURTEMPLEBRIDGENE10_BRIDGERETRACT = 2427
    AIURTEMPLEBRIDGENE12OUT_BRIDGEEXTEND = 2429
    AIURTEMPLEBRIDGENE12_BRIDGERETRACT = 2431
    AIURTEMPLEBRIDGENW8OUT_BRIDGEEXTEND = 2433
    AIURTEMPLEBRIDGENW8_BRIDGERETRACT = 2435
    AIURTEMPLEBRIDGENW10OUT_BRIDGEEXTEND = 2437
    AIURTEMPLEBRIDGENW10_BRIDGERETRACT = 2439
    AIURTEMPLEBRIDGENW12OUT_BRIDGEEXTEND = 2441
    AIURTEMPLEBRIDGENW12_BRIDGERETRACT = 2443
    SHAKURASLIGHTBRIDGENE8OUT_BRIDGEEXTEND = 2445
    SHAKURASLIGHTBRIDGENE8_BRIDGERETRACT = 2447
    SHAKURASLIGHTBRIDGENE10OUT_BRIDGEEXTEND = 2449
    SHAKURASLIGHTBRIDGENE10_BRIDGERETRACT = 2451
    SHAKURASLIGHTBRIDGENE12OUT_BRIDGEEXTEND = 2453
    SHAKURASLIGHTBRIDGENE12_BRIDGERETRACT = 2455
    SHAKURASLIGHTBRIDGENW8OUT_BRIDGEEXTEND = 2457
    SHAKURASLIGHTBRIDGENW8_BRIDGERETRACT = 2459
    SHAKURASLIGHTBRIDGENW10OUT_BRIDGEEXTEND = 2461
    SHAKURASLIGHTBRIDGENW10_BRIDGERETRACT = 2463
    SHAKURASLIGHTBRIDGENW12OUT_BRIDGEEXTEND = 2465
    SHAKURASLIGHTBRIDGENW12_BRIDGERETRACT = 2467
    VOIDMPIMMORTALREVIVEREBUILD_IMMORTAL = 2469
    VOIDMPIMMORTALREVIVEDEATH_IMMORTAL = 2471
    ARBITERMPSTASISFIELD_ARBITERMPSTASISFIELD = 2473
    ARBITERMPRECALL_ARBITERMPRECALL = 2475
    CORSAIRMPDISRUPTIONWEB_CORSAIRMPDISRUPTIONWEB = 2477
    MORPHTOGUARDIANMP_MORPHTOGUARDIANMP = 2479
    MORPHTOGUARDIANMP_CANCEL = 2480
    MORPHTODEVOURERMP_MORPHTODEVOURERMP = 2481
    MORPHTODEVOURERMP_CANCEL = 2482
    DEFILERMPCONSUME_DEFILERMPCONSUME = 2483
    DEFILERMPDARKSWARM_DEFILERMPDARKSWARM = 2485
    DEFILERMPPLAGUE_DEFILERMPPLAGUE = 2487
    DEFILERMPBURROW_BURROWDOWN = 2489
    DEFILERMPBURROW_CANCEL = 2490
    DEFILERMPUNBURROW_BURROWUP = 2491
    QUEENMPENSNARE_QUEENMPENSNARE = 2493
    QUEENMPSPAWNBROODLINGS_QUEENMPSPAWNBROODLINGS = 2495
    QUEENMPINFESTCOMMANDCENTER_QUEENMPINFESTCOMMANDCENTER = 2497
    LIGHTNINGBOMB_LIGHTNINGBOMB = 2499
    GRAPPLE_GRAPPLE = 2501
    ORACLESTASISTRAP_ORACLEBUILDSTASISTRAP = 2503
    BUILD_STASISTRAP = 2505
    CANCEL_STASISTRAP = 2535
    ORACLESTASISTRAPACTIVATE_ACTIVATESTASISWARD = 2536
    SELFREPAIR_SELFREPAIR = 2538
    SELFREPAIR_CANCEL = 2539
    AGGRESSIVEMUTATION_AGGRESSIVEMUTATION = 2540
    PARASITICBOMB_PARASITICBOMB = 2542
    ADEPTPHASESHIFT_ADEPTPHASESHIFT = 2544
    PURIFICATIONNOVAMORPH_PURIFICATIONNOVA = 2546
    PURIFICATIONNOVAMORPHBACK_PURIFICATIONNOVA = 2548
    BEHAVIOR_HOLDFIREON_LURKER = 2550
    BEHAVIOR_HOLDFIREOFF_LURKER = 2552
    LIBERATORMORPHTOAG_LIBERATORAGMODE = 2554
    LIBERATORMORPHTOAA_LIBERATORAAMODE = 2556
    MORPH_LIBERATORAGMODE = 2558
    MORPH_LIBERATORAAMODE = 2560
    TIMESTOP_TIMESTOP = 2562
    TIMESTOP_CANCEL = 2563
    AIURLIGHTBRIDGEABANDONEDNE8OUT_BRIDGEEXTEND = 2564
    AIURLIGHTBRIDGEABANDONEDNE8_BRIDGERETRACT = 2566
    AIURLIGHTBRIDGEABANDONEDNE10OUT_BRIDGEEXTEND = 2568
    AIURLIGHTBRIDGEABANDONEDNE10_BRIDGERETRACT = 2570
    AIURLIGHTBRIDGEABANDONEDNE12OUT_BRIDGEEXTEND = 2572
    AIURLIGHTBRIDGEABANDONEDNE12_BRIDGERETRACT = 2574
    AIURLIGHTBRIDGEABANDONEDNW8OUT_BRIDGEEXTEND = 2576
    AIURLIGHTBRIDGEABANDONEDNW8_BRIDGERETRACT = 2578
    AIURLIGHTBRIDGEABANDONEDNW10OUT_BRIDGEEXTEND = 2580
    AIURLIGHTBRIDGEABANDONEDNW10_BRIDGERETRACT = 2582
    AIURLIGHTBRIDGEABANDONEDNW12OUT_BRIDGEEXTEND = 2584
    AIURLIGHTBRIDGEABANDONEDNW12_BRIDGERETRACT = 2586
    KD8CHARGE_KD8CHARGE = 2588
    PENETRATINGSHOT_PENETRATINGSHOT = 2590
    CLOAKINGDRONE_CLOAKINGDRONE = 2592
    CANCEL_ADEPTPHASESHIFT = 2594
    CANCEL_ADEPTSHADEPHASESHIFT = 2596
    SLAYNELEMENTALGRAB_SLAYNELEMENTALGRAB = 2598
    MORPHTOCOLLAPSIBLEPURIFIERTOWERDEBRIS_CANCEL = 2601
    PORTCITY_BRIDGE_UNITNE8OUT_BRIDGEEXTEND = 2602
    PORTCITY_BRIDGE_UNITNE8_BRIDGERETRACT = 2604
    PORTCITY_BRIDGE_UNITSE8OUT_BRIDGEEXTEND = 2606
    PORTCITY_BRIDGE_UNITSE8_BRIDGERETRACT = 2608
    PORTCITY_BRIDGE_UNITNW8OUT_BRIDGEEXTEND = 2610
    PORTCITY_BRIDGE_UNITNW8_BRIDGERETRACT = 2612
    PORTCITY_BRIDGE_UNITSW8OUT_BRIDGEEXTEND = 2614
    PORTCITY_BRIDGE_UNITSW8_BRIDGERETRACT = 2616
    PORTCITY_BRIDGE_UNITNE10OUT_BRIDGEEXTEND = 2618
    PORTCITY_BRIDGE_UNITNE10_BRIDGERETRACT = 2620
    PORTCITY_BRIDGE_UNITSE10OUT_BRIDGEEXTEND = 2622
    PORTCITY_BRIDGE_UNITSE10_BRIDGERETRACT = 2624
    PORTCITY_BRIDGE_UNITNW10OUT_BRIDGEEXTEND = 2626
    PORTCITY_BRIDGE_UNITNW10_BRIDGERETRACT = 2628
    PORTCITY_BRIDGE_UNITSW10OUT_BRIDGEEXTEND = 2630
    PORTCITY_BRIDGE_UNITSW10_BRIDGERETRACT = 2632
    PORTCITY_BRIDGE_UNITNE12OUT_BRIDGEEXTEND = 2634
    PORTCITY_BRIDGE_UNITNE12_BRIDGERETRACT = 2636
    PORTCITY_BRIDGE_UNITSE12OUT_BRIDGEEXTEND = 2638
    PORTCITY_BRIDGE_UNITSE12_BRIDGERETRACT = 2640
    PORTCITY_BRIDGE_UNITNW12OUT_BRIDGEEXTEND = 2642
    PORTCITY_BRIDGE_UNITNW12_BRIDGERETRACT = 2644
    PORTCITY_BRIDGE_UNITSW12OUT_BRIDGEEXTEND = 2646
    PORTCITY_BRIDGE_UNITSW12_BRIDGERETRACT = 2648
    PORTCITY_BRIDGE_UNITN8OUT_BRIDGEEXTEND = 2650
    PORTCITY_BRIDGE_UNITN8_BRIDGERETRACT = 2652
    PORTCITY_BRIDGE_UNITS8OUT_BRIDGEEXTEND = 2654
    PORTCITY_BRIDGE_UNITS8_BRIDGERETRACT = 2656
    PORTCITY_BRIDGE_UNITE8OUT_BRIDGEEXTEND = 2658
    PORTCITY_BRIDGE_UNITE8_BRIDGERETRACT = 2660
    PORTCITY_BRIDGE_UNITW8OUT_BRIDGEEXTEND = 2662
    PORTCITY_BRIDGE_UNITW8_BRIDGERETRACT = 2664
    PORTCITY_BRIDGE_UNITN10OUT_BRIDGEEXTEND = 2666
    PORTCITY_BRIDGE_UNITN10_BRIDGERETRACT = 2668
    PORTCITY_BRIDGE_UNITS10OUT_BRIDGEEXTEND = 2670
    PORTCITY_BRIDGE_UNITS10_BRIDGERETRACT = 2672
    PORTCITY_BRIDGE_UNITE10OUT_BRIDGEEXTEND = 2674
    PORTCITY_BRIDGE_UNITE10_BRIDGERETRACT = 2676
    PORTCITY_BRIDGE_UNITW10OUT_BRIDGEEXTEND = 2678
    PORTCITY_BRIDGE_UNITW10_BRIDGERETRACT = 2680
    PORTCITY_BRIDGE_UNITN12OUT_BRIDGEEXTEND = 2682
    PORTCITY_BRIDGE_UNITN12_BRIDGERETRACT = 2684
    PORTCITY_BRIDGE_UNITS12OUT_BRIDGEEXTEND = 2686
    PORTCITY_BRIDGE_UNITS12_BRIDGERETRACT = 2688
    PORTCITY_BRIDGE_UNITE12OUT_BRIDGEEXTEND = 2690
    PORTCITY_BRIDGE_UNITE12_BRIDGERETRACT = 2692
    PORTCITY_BRIDGE_UNITW12OUT_BRIDGEEXTEND = 2694
    PORTCITY_BRIDGE_UNITW12_BRIDGERETRACT = 2696
    TEMPESTDISRUPTIONBLAST_TEMPESTDISRUPTIONBLAST = 2698
    CANCEL_TEMPESTDISRUPTIONBLAST = 2699
    EFFECT_SHADOWSTRIDE = 2700
    EFFECT_SPAWNLOCUSTS = 2704
    LOCUSTMPFLYINGSWOOPATTACK_LOCUSTMPFLYINGSWOOP = 2706
    MORPH_OVERLORDTRANSPORT = 2708
    CANCEL_MORPHOVERLORDTRANSPORT = 2709
    EFFECT_GHOSTSNIPE = 2714
    PURIFYMORPHPYLON_MOTHERSHIPCOREWEAPON = 2716
    PURIFYMORPHPYLONBACK_MOTHERSHIPCOREWEAPON = 2718
    RESEARCH_SHADOWSTRIKE = 2720
    HEAL_MEDICHEAL = 2750
    LURKERASPECT_LURKER = 2752
    LURKERASPECT_CANCEL = 2753
    BURROWLURKERDOWN_BURROWDOWN = 2754
    BURROWLURKERDOWN_CANCEL = 2755
    BURROWLURKERUP_BURROWUP = 2756
    D8CHARGE_D8CHARGE = 2758
    DEFENSIVEMATRIX_DEFENSIVEMATRIX = 2760
    MISSILEPODS_MISSILEPODS = 2762
    LOKIMISSILEPODS_MISSILEPODS = 2764
    HUTTRANSPORT_HUTLOAD = 2766
    HUTTRANSPORT_HUTUNLOADALL = 2767
    LEVIATHANSPAWNBROODLORD_SPAWNBROODLORD = 2773
    SS_CARRIERBOSSATTACKLAUNCH_SS_SHOOTING = 2775
    SS_CARRIERSPAWNINTERCEPTOR_SS_CARRIERSPAWNINTERCEPTOR = 2777
    SS_CARRIERBOSSATTACKTARGET_SS_SHOOTING = 2779
    SS_FIGHTERBOMB_SS_FIGHTERBOMB = 2781
    SS_PHOENIXSHOOTING_SS_SHOOTING = 2785
    SS_BATTLECRUISERMISSILEATTACK_SS_SHOOTING = 2789
    SS_LEVIATHANSPAWNBOMBS_SS_LEVIATHANSPAWNBOMBS = 2791
    SS_BATTLECRUISERHUNTERSEEKERATTACK_SS_SHOOTING = 2793
    SS_LEVIATHANTENTACLEATTACKL1NODELAY_SS_LEVIATHANTENTACLEATTACKL1NODELAY = 2797
    SS_LEVIATHANTENTACLEATTACKL2NODELAY_SS_LEVIATHANTENTACLEATTACKL2NODELAY = 2799
    SS_LEVIATHANTENTACLEATTACKR1NODELAY_SS_LEVIATHANTENTACLEATTACKR1NODELAY = 2801
    SS_LEVIATHANTENTACLEATTACKR2NODELAY_SS_LEVIATHANTENTACLEATTACKR2NODELAY = 2803
    SS_SCIENCEVESSELTELEPORT_ZERATULBLINK = 2805
    SS_TERRATRONBEAMATTACK_SS_TERRATRONBEAMATTACK = 2807
    SS_TERRATRONSAWATTACK_SS_TERRATRONSAWATTACK = 2809
    SS_WRAITHATTACK_SS_SHOOTING = 2811
    SS_SWARMGUARDIANATTACK_SS_SHOOTING = 2813
    SS_SCOUTATTACK_SS_SHOOTING = 2819
    SS_INTERCEPTORATTACK_SS_SHOOTING = 2821
    SS_CORRUPTORATTACK_SS_SHOOTING = 2823
    SS_LEVIATHANTENTACLEATTACKL2_SS_LEVIATHANTENTACLEATTACKL2 = 2825
    SS_LEVIATHANTENTACLEATTACKR1_SS_LEVIATHANTENTACLEATTACKR1 = 2827
    SS_LEVIATHANTENTACLEATTACKL1_SS_LEVIATHANTENTACLEATTACKL1 = 2829
    SS_LEVIATHANTENTACLEATTACKR2_SS_LEVIATHANTENTACLEATTACKR2 = 2831
    SS_SCIENCEVESSELATTACK_SS_SHOOTING = 2833
    LURKERASPECTFROMHYDRALISKBURROWED_LURKERFROMHYDRALISKBURROWED = 2836
    LURKERASPECTFROMHYDRALISKBURROWED_CANCEL = 2837
    UPGRADETOLURKERDEN_LURKERDEN = 2838
    UPGRADETOLURKERDEN_CANCEL = 2839
    ADVANCEDCONSTRUCTION_CANCEL = 2840
    BUILDINPROGRESSNONCANCELLABLE_CANCEL = 2842
    INFESTEDVENTSPAWNCORRUPTOR_SPAWNCORRUPTOR = 2844
    INFESTEDVENTSPAWNBROODLORD_SPAWNBROODLORD = 2846
    IRRADIATE_IRRADIATE = 2848
    IRRADIATE_CANCEL = 2849
    INFESTEDVENTSPAWNMUTALISK_LEVIATHANSPAWNMUTALISK = 2850
    MAKEVULTURESPIDERMINES_SPIDERMINEREPLENISH = 2852
    MEDIVACDOUBLEBEAMHEAL_HEAL = 2872
    MINDCONTROL_MINDCONTROL = 2874
    OBLITERATE_OBLITERATE = 2876
    VOODOOSHIELD_VOODOOSHIELD = 2878
    RELEASEMINION_RELEASEMINION = 2880
    ULTRASONICPULSE_ULTRASONICPULSE = 2882
    ARCHIVESEAL_ARCHIVESEAL = 2884
    ARTANISVORTEX_VORTEX = 2886
    ARTANISWORMHOLETRANSIT_WORMHOLETRANSIT = 2888
    BUNKERATTACK_BUNKERATTACK = 2890
    BUNKERATTACK_ATTACKTOWARDS = 2891
    BUNKERATTACK_ATTACKBARRAGE = 2892
    BUNKERSTOP_STOPBUNKER = 2893
    BUNKERSTOP_HOLDFIRESPECIAL = 2894
    CANCELTERRAZINEHARVEST_CANCEL = 2899
    LEVIATHANSPAWNMUTALISK_LEVIATHANSPAWNMUTALISK = 2901
    PARKCOLONISTVEHICLE_PARKCOLONISTVEHICLE = 2903
    STARTCOLONISTVEHICLE_STARTCOLONISTVEHICLE = 2905
    CONSUMPTION_CONSUMPTION = 2907
    CONSUMEDNA_CONSUMEDNA = 2909
    EGGPOP_EGGPOP = 2911
    EXPERIMENTALPLASMAGUN_EXPERIMENTALPLASMAGUN = 2913
    GATHERSPECIALOBJECT_GATHERSPECIALOBJECT = 2915
    LOKIUNDOCK_LIFT = 2919
    MINDBLAST_MINDBLAST = 2921
    MORPHTOINFESTEDCIVILIAN_MORPHTOINFESTEDCIVILIAN = 2923
    QUEENSHOCKWAVE_QUEENSHOCKWAVE = 2925
    TAURENOUTHOUSELIFTOFF_TAURENOUTHOUSEFLY = 2927
    TAURENOUTHOUSETRANSPORT_LOADTAURENOUTHOUSE = 2929
    TAURENOUTHOUSETRANSPORT_UNLOADTAURENOUTHOUSE = 2930
    TYCHUS03OMEGASTORM_OMEGASTORM = 2934
    RAYNORSNIPE_RAYNORSNIPE = 2936
    BONESHEAL_BONESHEAL = 2938
    BONESTOSSGRENADE_TOSSGRENADETYCHUS = 2940
    HERCULESTRANSPORT_MEDIVACLOAD = 2942
    HERCULESTRANSPORT_MEDIVACUNLOADALL = 2944
    SPECOPSDROPSHIPTRANSPORT_MEDIVACLOAD = 2947
    SPECOPSDROPSHIPTRANSPORT_MEDIVACUNLOADALL = 2949
    DUSKWINGBANSHEECLOAKINGFIELD_CLOAKONBANSHEE = 2952
    DUSKWINGBANSHEECLOAKINGFIELD_CLOAKOFF = 2953
    HYPERIONYAMATOSPECIAL_HYPERIONYAMATOGUN = 2954
    INFESTABLEHUTTRANSPORT_HUTLOAD = 2956
    INFESTABLEHUTTRANSPORT_HUTUNLOADALL = 2957
    DUTCHPLACETURRET_DUTCHPLACETURRET = 2961
    BURROWINFESTEDCIVILIANDOWN_BURROWDOWN = 2963
    BURROWINFESTEDCIVILIANUP_BURROWUP = 2965
    SELENDISHANGAR_INTERCEPTOR = 2967
    SIEGEBREAKERSIEGE_SIEGEMODE = 2989
    SIEGEBREAKERUNSIEGE_UNSIEGE = 2991
    SOULCHANNEL_CANCEL = 2994
    SENTRYGUNBURROW_BURROWTURRET = 2999
    SENTRYGUNUNBURROW_UNBURROWTURRET = 3001
    GRAVITONPRISON_GRAVITONPRISON = 3005
    IMPLOSION_IMPLOSION = 3007
    OMEGASTORM_OMEGASTORM = 3009
    PSIONICSHOCKWAVE_PSIONICSHOCKWAVE = 3011
    HYBRIDFAOESTUN_HYBRIDFAOESTUN = 3013
    SUMMONMERCENARIES_HIREKELMORIANMINERS = 3015
    SUMMONMERCENARIES_HIREDEVILDOGS = 3016
    SUMMONMERCENARIES_HIRESPARTANCOMPANY = 3017
    SUMMONMERCENARIES_HIREHAMMERSECURITIES = 3018
    SUMMONMERCENARIES_HIRESIEGEBREAKERS = 3019
    SUMMONMERCENARIES_HIREHELSANGELS = 3020
    SUMMONMERCENARIES_HIREDUSKWING = 3021
    SUMMONMERCENARIES_HIREDUKESREVENGE = 3022
    SUMMONMERCENARIESPH_HIREKELMORIANMINERSPH = 3045
    ENERGYNOVA_ENERGYNOVA = 3075
    THEMOROSDEVICE_THEMOROSDEVICE = 3077
    TOSSGRENADE_TOSSGRENADE = 3079
    VOIDSEEKERTRANSPORT_MEDIVACLOAD = 3081
    VOIDSEEKERTRANSPORT_MEDIVACUNLOADALL = 3083
    TERRANBUILDDROP_SUPPLYDEPOTDROP = 3086
    TERRANBUILDDROP_CANCEL = 3116
    ODINNUCLEARSTRIKE_ODINNUKECALLDOWN = 3117
    ODINNUCLEARSTRIKE_CANCEL = 3118
    ODINWRECKAGE_ODIN = 3119
    RESEARCHLABTRANSPORT_HUTLOAD = 3121
    RESEARCHLABTRANSPORT_HUTUNLOADALL = 3122
    COLONYSHIPTRANSPORT_MEDIVACLOAD = 3126
    COLONYSHIPTRANSPORT_MEDIVACUNLOADALL = 3128
    COLONYINFESTATION_COLONYINFESTATION = 3131
    DOMINATION_DOMINATION = 3133
    DOMINATION_CANCEL = 3134
    KARASSPLASMASURGE_KARASSPLASMASURGE = 3135
    KARASSPSISTORM_PSISTORM = 3137
    HYBRIDBLINK_ZERATULBLINK = 3139
    HYBRIDCPLASMABLAST_HYBRIDCPLASMABLAST = 3141
    HEROARMNUKE_NUKEARM = 3143
    HERONUCLEARSTRIKE_NUKECALLDOWN = 3163
    HERONUCLEARSTRIKE_CANCEL = 3164
    ODINBARRAGE_ODINBARRAGE = 3165
    ODINBARRAGE_CANCEL = 3166
    PURIFIERTOGGLEPOWER_PURIFIERPOWERDOWN = 3167
    PURIFIERTOGGLEPOWER_PURIFIERPOWERUP = 3168
    PHASEMINEBLAST_PHASEMINEBLAST = 3169
    VOIDSEEKERPHASEMINEBLAST_PHASEMINEBLAST = 3171
    TRANSPORTTRUCKTRANSPORT_TRANSPORTTRUCKLOAD = 3173
    TRANSPORTTRUCKTRANSPORT_TRANSPORTTRUCKUNLOADALL = 3174
    VAL03QUEENOFBLADESBURROW_BURROWDOWN = 3178
    VAL03QUEENOFBLADESDEEPTUNNEL_DEEPTUNNEL = 3180
    VAL03QUEENOFBLADESUNBURROW_BURROWUP = 3182
    LOKIYAMATO_LOKIYAMATOGUN = 3188
    DUKESREVENGEYAMATO_YAMATOGUN = 3190
    ZERATULBLINK_ZERATULBLINK = 3192
    ROGUEGHOSTCLOAK_CLOAKONSPECTRE = 3194
    ROGUEGHOSTCLOAK_CLOAKOFF = 3195
    VULTURESPIDERMINES_SPIDERMINE = 3196
    VULTUREQUEUE3_CANCEL = 3198
    VULTUREQUEUE3_CANCELSLOT = 3199
    SUPERWARPGATETRAIN_ZEALOT = 3200
    SUPERWARPGATETRAIN_STALKER = 3201
    SUPERWARPGATETRAIN_IMMORTAL = 3202
    SUPERWARPGATETRAIN_HIGHTEMPLAR = 3203
    SUPERWARPGATETRAIN_DARKTEMPLAR = 3204
    SUPERWARPGATETRAIN_SENTRY = 3205
    SUPERWARPGATETRAIN_CARRIER = 3206
    SUPERWARPGATETRAIN_PHOENIX = 3207
    SUPERWARPGATETRAIN_VOIDRAY = 3208
    SUPERWARPGATETRAIN_ARCHON = 3209
    SUPERWARPGATETRAIN_WARPINZERATUL = 3210
    SUPERWARPGATETRAIN_WARPINURUN = 3211
    SUPERWARPGATETRAIN_WARPINMOHANDAR = 3212
    SUPERWARPGATETRAIN_WARPINSELENDIS = 3213
    SUPERWARPGATETRAIN_WARPINSCOUT = 3214
    SUPERWARPGATETRAIN_COLOSSUS = 3215
    SUPERWARPGATETRAIN_WARPPRISM = 3216
    BURROWOMEGALISKDOWN_BURROWDOWN = 3220
    BURROWOMEGALISKUP_BURROWUP = 3222
    BURROWINFESTEDABOMINATIONDOWN_BURROWDOWN = 3224
    BURROWINFESTEDABOMINATIONUP_BURROWUP = 3226
    BURROWHUNTERKILLERDOWN_BURROWDOWN = 3228
    BURROWHUNTERKILLERDOWN_CANCEL = 3229
    BURROWHUNTERKILLERUP_BURROWUP = 3230
    NOVASNIPE_NOVASNIPE = 3232
    VORTEXPURIFIER_VORTEX = 3234
    TALDARIMVORTEX_VORTEX = 3236
    PURIFIERPLANETCRACKER_PLANETCRACKER = 3238
    BURROWINFESTEDTERRANCAMPAIGNDOWN_BURROWDOWN = 3240
    BURROWINFESTEDTERRANCAMPAIGNUP_BURROWUP = 3242
    INFESTEDMONSTERTRAIN_INFESTEDCIVILIAN = 3244
    INFESTEDMONSTERTRAIN_INFESTEDTERRANCAMPAIGN = 3245
    INFESTEDMONSTERTRAIN_INFESTEDABOMINATION = 3246
    BIODOMETRANSPORT_BIODOMELOAD = 3274
    BIODOMETRANSPORT_BIODOMEUNLOADALL = 3275
    ATTACKALLOWSINVULNERABLE_ATTACKALLOWSINVULNERABLE = 3295
    ATTACKALLOWSINVULNERABLE_ATTACKTOWARDS = 3296
    ATTACKALLOWSINVULNERABLE_ATTACKBARRAGE = 3297
    ZERATULSTUN_ZERATULSTUN = 3298
    WRAITHCLOAK_CLOAKOFF = 3301
    BARRACKSTECHREACTORMORPH_TECHLABBARRACKS = 3304
    FACTORYTECHREACTORMORPH_TECHLABFACTORY = 3306
    STARPORTTECHREACTORMORPH_TECHLABSTARPORT = 3308
    SS_FIGHTERSHOOTING_SS_SHOOTING = 3310
    RAYNORC4_PLANTC4CHARGE = 3312
    DUKESREVENGEDEFENSIVEMATRIX_DEFENSIVEMATRIX = 3314
    DUKESREVENGEMISSILEPODS_MISSILEPODS = 3316
    THORWRECKAGE_THOR = 3318
    _330MMBARRAGECANNONS_330MMBARRAGECANNONS = 3320
    _330MMBARRAGECANNONS_CANCEL = 3321
    THORREBORN_THOR = 3322
    THORREBORN_CANCEL = 3323
    SPECTRENUKE_SPECTRENUKECALLDOWN = 3324
    SPECTRENUKE_CANCEL = 3325
    SPECTRENUKESILOARMMAGAZINE_SPECTRENUKEARM = 3327
    COLONISTSHIPLIFTOFF_LIFT = 3346
    COLONISTSHIPLAND_LAND = 3348
    BIODOMECOMMANDLIFTOFF_LIFT = 3350
    BIODOMECOMMANDLAND_LAND = 3352
    HERCULESLIFTOFF_LIFT = 3354
    HERCULESLAND_HERCULESLAND = 3356
    LIGHTBRIDGEOFF_LIGHTBRIDGEOFF = 3358
    LIGHTBRIDGEON_LIGHTBRIDGEON = 3360
    LIBRARYDOWN_LIBRARYDOWN = 3362
    LIBRARYUP_LIBRARYUP = 3364
    TEMPLEDOORDOWN_TEMPLEDOORDOWN = 3366
    TEMPLEDOORUP_TEMPLEDOORUP = 3368
    TEMPLEDOORDOWNURDL_TEMPLEDOORDOWNURDL = 3370
    TEMPLEDOORUPURDL_TEMPLEDOORUPURDL = 3372
    PSYTROUSOXIDE_PSYTROUSOXIDEON = 3374
    PSYTROUSOXIDE_PSYTROUSOXIDEOFF = 3375
    BIOPLASMIDDISCHARGE_BIOPLASMIDDISCHARGE = 3378
    WRECKINGCREWASSAULTMODE_ASSAULTMODE = 3380
    WRECKINGCREWFIGHTERMODE_FIGHTERMODE = 3382
    BIOSTASIS_BIOSTASIS = 3384
    COLONISTTRANSPORTTRANSPORT_COLONISTTRANSPORTLOAD = 3386
    COLONISTTRANSPORTTRANSPORT_COLONISTTRANSPORTUNLOADALL = 3387
    DROPTOSUPPLYDEPOT_RAISE = 3391
    REFINERYTOAUTOMATEDREFINERY_RAISE = 3393
    HELIOSCRASHMORPH_CRASHMORPH = 3395
    NANOREPAIR_HEAL = 3397
    PICKUP_PICKUP = 3399
    PICKUPARCADE_PICKUP = 3401
    PICKUPGAS100_PICKUPGAS100 = 3403
    PICKUPMINERALS100_PICKUPMINERALS100 = 3405
    TAURENSTIMPACK_STIM = 3423
    TESTREVIVE_SCV = 3454
    TESTINTERACT_DESIGNATE = 3514
    CLIFFDOOROPEN0_SPACEPLATFORMDOOROPEN = 3515
    CLIFFDOORCLOSE0_SPACEPLATFORMDOORCLOSE = 3517
    CLIFFDOOROPEN1_SPACEPLATFORMDOOROPEN = 3519
    CLIFFDOORCLOSE1_SPACEPLATFORMDOORCLOSE = 3521
    DESTRUCTIBLEGATEDIAGONALBLURLOWERED_GATEOPEN = 3523
    DESTRUCTIBLEGATEDIAGONALULBRLOWERED_GATEOPEN = 3525
    DESTRUCTIBLEGATESTRAIGHTHORIZONTALBFLOWERED_GATEOPEN = 3527
    DESTRUCTIBLEGATESTRAIGHTHORIZONTALLOWERED_GATEOPEN = 3529
    DESTRUCTIBLEGATESTRAIGHTVERTICALLFLOWERED_GATEOPEN = 3531
    DESTRUCTIBLEGATESTRAIGHTVERTICALLOWERED_GATEOPEN = 3533
    DESTRUCTIBLEGATEDIAGONALBLUR_GATECLOSE = 3535
    DESTRUCTIBLEGATEDIAGONALULBR_GATECLOSE = 3537
    DESTRUCTIBLEGATESTRAIGHTHORIZONTALBF_GATECLOSE = 3539
    DESTRUCTIBLEGATESTRAIGHTHORIZONTAL_GATECLOSE = 3541
    DESTRUCTIBLEGATESTRAIGHTVERTICALLF_GATECLOSE = 3543
    DESTRUCTIBLEGATESTRAIGHTVERTICAL_GATECLOSE = 3545
    TESTLEARN_TESTLEARN = 3547
    TESTLEVELEDSPELL_YAMATOGUN = 3567
    METALGATEDIAGONALBLURLOWERED_GATEOPEN = 3569
    METALGATEDIAGONALULBRLOWERED_GATEOPEN = 3571
    METALGATESTRAIGHTHORIZONTALBFLOWERED_GATEOPEN = 3573
    METALGATESTRAIGHTHORIZONTALLOWERED_GATEOPEN = 3575
    METALGATESTRAIGHTVERTICALLFLOWERED_GATEOPEN = 3577
    METALGATESTRAIGHTVERTICALLOWERED_GATEOPEN = 3579
    METALGATEDIAGONALBLUR_GATECLOSE = 3581
    METALGATEDIAGONALULBR_GATECLOSE = 3583
    METALGATESTRAIGHTHORIZONTALBF_GATECLOSE = 3585
    METALGATESTRAIGHTHORIZONTAL_GATECLOSE = 3587
    METALGATESTRAIGHTVERTICALLF_GATECLOSE = 3589
    METALGATESTRAIGHTVERTICAL_GATECLOSE = 3591
    SECURITYGATEDIAGONALBLURLOWERED_GATEOPEN = 3593
    SECURITYGATEDIAGONALULBRLOWERED_GATEOPEN = 3595
    SECURITYGATESTRAIGHTHORIZONTALBFLOWERED_GATEOPEN = 3597
    SECURITYGATESTRAIGHTHORIZONTALLOWERED_GATEOPEN = 3599
    SECURITYGATESTRAIGHTVERTICALLFLOWERED_GATEOPEN = 3601
    SECURITYGATESTRAIGHTVERTICALLOWERED_GATEOPEN = 3603
    SECURITYGATEDIAGONALBLUR_GATECLOSE = 3605
    SECURITYGATEDIAGONALULBR_GATECLOSE = 3607
    SECURITYGATESTRAIGHTHORIZONTALBF_GATECLOSE = 3609
    SECURITYGATESTRAIGHTHORIZONTAL_GATECLOSE = 3611
    SECURITYGATESTRAIGHTVERTICALLF_GATECLOSE = 3613
    SECURITYGATESTRAIGHTVERTICAL_GATECLOSE = 3615
    CHANGESHRINETERRAN_CHANGESHRINETERRAN = 3617
    CHANGESHRINEPROTOSS_CHANGESHRINEPROTOSS = 3619
    SPECTREHOLDFIRE_SPECTREHOLDFIRE = 3621
    SPECTREWEAPONSFREE_WEAPONSFREE = 3623
    GWALEARN_TESTLEARN = 3625
    LIGHTBRIDGEOFFTOPRIGHT_LIGHTBRIDGEOFF = 3647
    LIGHTBRIDGEONTOPRIGHT_LIGHTBRIDGEON = 3649
    TESTHEROGRAB_GRABZERGLING = 3651
    TESTHEROTHROW_THROWZERGLING = 3653
    TESTHERODEBUGMISSILEABILITY_TESTHERODEBUGMISSILEABILITY = 3655
    TESTHERODEBUGTRACKINGABILITY_TESTHERODEBUGTRACKINGABILITY = 3657
    TESTHERODEBUGTRACKINGABILITY_CANCEL = 3658
    CANCEL = 3659
    HALT = 3660
    BURROWDOWN = 3661
    BURROWUP = 3662
    LOADALL = 3663
    UNLOADALL = 3664
    STOP = 3665
    HARVEST_GATHER = 3666
    HARVEST_RETURN = 3667
    LOAD = 3668
    UNLOADALLAT = 3669
    CANCEL_LAST = 3671
    CANCEL_SLOT = 3672
    RALLY_UNITS = 3673
    ATTACK = 3674
    EFFECT_STIM = 3675
    BEHAVIOR_CLOAKON = 3676
    BEHAVIOR_CLOAKOFF = 3677
    LAND = 3678
    LIFT = 3679
    MORPH_ROOT = 3680
    MORPH_UPROOT = 3681
    BUILD_TECHLAB = 3682
    BUILD_REACTOR = 3683
    EFFECT_SPRAY = 3684
    EFFECT_REPAIR = 3685
    EFFECT_MASSRECALL = 3686
    EFFECT_BLINK = 3687
    BEHAVIOR_HOLDFIREON = 3688
    BEHAVIOR_HOLDFIREOFF = 3689
    RALLY_WORKERS = 3690
    BUILD_CREEPTUMOR = 3691
    RESEARCH_PROTOSSAIRARMOR = 3692
    RESEARCH_PROTOSSAIRWEAPONS = 3693
    RESEARCH_PROTOSSGROUNDARMOR = 3694
    RESEARCH_PROTOSSGROUNDWEAPONS = 3695
    RESEARCH_PROTOSSSHIELDS = 3696
    RESEARCH_TERRANINFANTRYARMOR = 3697
    RESEARCH_TERRANINFANTRYWEAPONS = 3698
    RESEARCH_TERRANSHIPWEAPONS = 3699
    RESEARCH_TERRANVEHICLEANDSHIPPLATING = 3700
    RESEARCH_TERRANVEHICLEWEAPONS = 3701
    RESEARCH_ZERGFLYERARMOR = 3702
    RESEARCH_ZERGFLYERATTACK = 3703
    RESEARCH_ZERGGROUNDARMOR = 3704
    RESEARCH_ZERGMELEEWEAPONS = 3705
    RESEARCH_ZERGMISSILEWEAPONS = 3706
    CANCEL_VOIDRAYPRISMATICALIGNMENT = 3707
    RESEARCH_ADAPTIVETALONS = 3709
    LURKERDENRESEARCH_RESEARCHLURKERRANGE = 3710
    MORPH_OBSERVERMODE = 3739
    MORPH_SURVEILLANCEMODE = 3741
    MORPH_OVERSIGHTMODE = 3743
    MORPH_OVERSEERMODE = 3745
    EFFECT_INTERFERENCEMATRIX = 3747
    EFFECT_REPAIRDRONE = 3749
    EFFECT_REPAIR_REPAIRDRONE = 3751
    EFFECT_ANTIARMORMISSILE = 3753
    EFFECT_CHRONOBOOSTENERGYCOST = 3755
    EFFECT_MASSRECALL_NEXUS = 3757
    NEXUSSHIELDRECHARGE_NEXUSSHIELDRECHARGE = 3759
    NEXUSSHIELDRECHARGEONPYLON_NEXUSSHIELDRECHARGEONPYLON = 3761
    INFESTORENSNARE_INFESTORENSNARE = 3763
    EFFECT_RESTORE = 3765
    NEXUSSHIELDOVERCHARGE_NEXUSSHIELDOVERCHARGE = 3767
    NEXUSSHIELDOVERCHARGEOFF_NEXUSSHIELDOVERCHARGEOFF = 3769
    ATTACK_BATTLECRUISER = 3771
    BATTLECRUISERATTACK_ATTACKTOWARDS = 3772
    BATTLECRUISERATTACK_ATTACKBARRAGE = 3773
    BATTLECRUISERATTACKEVALUATOR_MOTHERSHIPCOREATTACK = 3774
    MOVE_BATTLECRUISER = 3776
    PATROL_BATTLECRUISER = 3777
    HOLDPOSITION_BATTLECRUISER = 3778
    BATTLECRUISERMOVE_ACQUIREMOVE = 3779
    BATTLECRUISERMOVE_TURN = 3780
    BATTLECRUISERSTOPEVALUATOR_STOP = 3781
    STOP_BATTLECRUISER = 3783
    BATTLECRUISERSTOP_HOLDFIRE = 3784
    BATTLECRUISERSTOP_CHEER = 3785
    BATTLECRUISERSTOP_DANCE = 3786
    VIPERPARASITICBOMBRELAY_PARASITICBOMB = 3789
    PARASITICBOMBRELAYDODGE_PARASITICBOMB = 3791
    HOLDPOSITION = 3793
    MOVE = 3794
    PATROL = 3795
    UNLOADUNIT = 3796
    LOADOUTSPRAY_LOADOUTSPRAY1 = 3797
    LOADOUTSPRAY_LOADOUTSPRAY2 = 3798
    LOADOUTSPRAY_LOADOUTSPRAY3 = 3799
    LOADOUTSPRAY_LOADOUTSPRAY4 = 3800
    LOADOUTSPRAY_LOADOUTSPRAY5 = 3801
    LOADOUTSPRAY_LOADOUTSPRAY6 = 3802
    LOADOUTSPRAY_LOADOUTSPRAY7 = 3803
    LOADOUTSPRAY_LOADOUTSPRAY8 = 3804
    LOADOUTSPRAY_LOADOUTSPRAY9 = 3805
    LOADOUTSPRAY_LOADOUTSPRAY10 = 3806
    LOADOUTSPRAY_LOADOUTSPRAY11 = 3807
    LOADOUTSPRAY_LOADOUTSPRAY12 = 3808
    LOADOUTSPRAY_LOADOUTSPRAY13 = 3809
    LOADOUTSPRAY_LOADOUTSPRAY14 = 3810
    MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPLEFTGREEN_CANCEL = 3967
    MORPHTOCOLLAPSIBLEROCKTOWERDEBRISRAMPRIGHTGREEN_CANCEL = 3970
    BATTERYOVERCHARGE_BATTERYOVERCHARGE = 4107
    AMORPHOUSARMORCLOUD_AMORPHOUSARMORCLOUD = 4109
    SHIELDBATTERYRECHARGEEX5_SHIELDBATTERYRECHARGE = 4111
    SHIELDBATTERYRECHARGEEX5_STOP = 4112

    def __repr__(self):
        return f"AbilityId.{self.name}"


for item in AbilityId:
    globals()[item.name] = item
