# DO NOT EDIT!
# This file was automatically generated by "generate_dicts_from_data_json.py"

__all__ = [
    'generic_redirect_abilities', 'unit_abilities', 'unit_research_abilities', 'unit_tech_alias',
    'unit_train_build_abilities', 'unit_trained_from', 'unit_unit_alias', 'upgrade_researched_from'
]
